@@ -1,4 +1,4 @@
-/* $Id: dot.c,v 1.28 2006/09/11 18:33:58 erg Exp $ $Revision: 1.28 $ */
+/* $Id: dot.c,v 1.29 2007/07/17 21:45:10 erg Exp $ $Revision: 1.29 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -24,7 +24,11 @@
 
 #include "builddate.h"
 #include "gvc.h"
+#ifdef GVDLL
+__declspec(dllimport) boolean MemTest;
+#else
 #include "globals.h"
+#endif
 
 #include <time.h>
 #ifdef HAVE_UNISTD_H
