@@ -1,4 +1,4 @@
-/* $Id: actions.c,v 1.3 2008/01/09 22:36:19 erg Exp $ $Revision: 1.3 $ */
+/* $Id: actions.c,v 1.4 2008/06/20 20:47:50 erg Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -106,7 +106,7 @@ void nodeInduce(Agraph_t * selected)
 	return;
 #ifdef USE_CGRAPH
     for (n = agfstnode(selected); n; n = agnxtnode(selected, n)) {
-	for (e = agfstout(selected, n); e; e = agnxtout(selected, e)) {
+	for (e = agfstout(base, n); e; e = agnxtout(base, e)) {
 #else
     for (n = agfstnode(selected); n; n = agnxtnode(n)) {
 	for (e = agfstout(agsubnode(base, n, FALSE)); e; e = agnxtout(e)) {
