@@ -1,4 +1,4 @@
-/* $Id: gvpr.c,v 1.8 2008/01/09 22:36:19 erg Exp $ $Revision: 1.8 $ */
+/* $Id: gvpr.c,v 1.10 2008/06/16 17:58:15 erg Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -26,6 +26,8 @@
 #endif
 #ifdef HAVE_UNISTD_H
 #include	<unistd.h>
+#else
+#include	<compat_unistd.h>
 #endif
 #include <gprstate.h>
 #ifdef USE_CGRAPH
@@ -702,9 +704,13 @@ int main(int argc, char *argv[])
 		(state->target) && !agnnodes(state->target))
 		agdelete(state->curgraph, state->target);
 
-	    /* output graph, if necessary */
-	    if (state->outgraph && agnnodes(state->outgraph))
-		agwrite(state->outgraph, options.outFile);
+	    /* output graph, if necessary
+             * For this, the outgraph must be defined, and either
+             * be non-empty or the -c option was used.
+             */
+	    if (state->outgraph && 
+		(agnnodes(state->outgraph) || (options.compflags & SRCOUT)))
+		    agwrite(state->outgraph, options.outFile);
 
 	    chkClose(state->curgraph);
 	    state->target = 0;
