@@ -1,4 +1,4 @@
-/* $Id: queue.h,v 1.1.1.1 2004/12/23 04:02:24 ellson Exp $ $Revision: 1.1.1.1 $ */
+/* $Id: queue.h,v 1.2 2008/01/09 22:36:19 erg Exp $ $Revision: 1.2 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -21,7 +21,11 @@ extern "C" {
 #ifndef QUEUE_H
 #define QUEUE_H
 
+#ifdef USE_CGRAPH
+#include <cgraph.h>
+#else
 #include <agraph.h>
+#endif
 
     typedef Dt_t queue;
 
