@@ -1,4 +1,4 @@
-/* $Id: common.c,v 1.4 2006/06/27 12:43:47 ellson Exp $ $Revision: 1.4 $ */
+/* $Id: common.c,v 1.6 2007/01/12 17:25:55 erg Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -424,7 +424,7 @@ void panic2 (char *file, int line, char *func, char *fmt, ...) {
 }
 
 #ifdef FEATURE_MS
-int printf (const char *fmt, ...) {
+int gprintf (const char *fmt, ...) {
     va_list args;
     char buf[10240];
     int l;
@@ -442,3 +442,4 @@ int printf (const char *fmt, ...) {
     va_end(args);
 }
 #endif
+
