@@ -1,4 +1,4 @@
-/* $Id: lefty.c,v 1.6 2007/01/04 21:35:54 erg Exp $ $Revision: 1.6 $ */ 
+/* $Id: lefty.c,v 1.8 2008/03/04 19:31:14 erg Exp $ $Revision: 1.8 $ */ 
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -210,10 +210,10 @@ eop:
 
 #else
 
-HANDLE hinstance, hprevinstance;
+HINSTANCE hinstance, hprevinstance;
 
-int PASCAL WinMain (
-    HANDLE hInstance, HANDLE hPrevInstance, LPSTR lpCmdLine, int nCmdShow
+int APIENTRY WinMain (
+    HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow
 ) {
     Tobj co;
     Psrc_t src;
@@ -362,7 +362,7 @@ static int processinput (int waitflag) {
             GFXmonitorfile (ioi), n--;
 #else
     for (ioi = 0, n = 0, evn = 0; ioi < ion; ioi++) {
-        if (!iop[ioi].inuse || !IOismonitored (ioi, inputfds))
+        if (!iop[ioi].inuse || !IOismonitored (ioi))
             continue;
         if (
             (iop[ioi].type == IO_FILE && canread (iop[ioi].ifp)) ||
