@@ -1,4 +1,4 @@
-/* $Id: gpcanvas.c,v 1.2 2005/04/08 20:45:34 erg Exp $ $Revision: 1.2 $ */
+/* $Id: gpcanvas.c,v 1.3 2008/02/12 20:59:59 erg Exp $ $Revision: 1.3 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -1123,7 +1123,7 @@ static void setgattr (Gwidget_t *widget, Ggattr_t *ap) {
         WPU->gattr.width = width, flag = TRUE;
     style = ap->style;
     if (style != WPU->gattr.style)
-        WPU->gattr.style = style, style = TRUE;
+        WPU->gattr.style = style, flag = TRUE;
 
     if (!flag)
         return;
