@@ -1,4 +1,4 @@
-/* $Id: filter.h,v 1.1 2008/02/29 15:44:31 arif Exp $ $Revision: 1.1 $ */
+/* $Id: filter.h,v 1.2 2008/03/19 21:43:58 erg Exp $ $Revision: 1.2 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,17 +18,16 @@
 #define FILTER_H
 #include "btree.h"
 
-typedef struct _tv_filters
-{
-	tv_filter** filters;
-	int filter_count;
-}tv_filters;
+typedef struct _tv_filters {
+    tv_filter **filters;
+    int filter_count;
+} tv_filters;
 
-int clear_filter(tv_filter* f);
-int init_filters(tv_filters* filters);
-int add_filter_to_filters(tv_filters* filters,tv_filter* filter);
-int clear_filters(tv_filters* filters);
-int union_filter(tv_filter* f1,tv_filter* f2);
-int intersect_filter(tv_filter* f1,tv_filter* f2);
+int clear_filter(tv_filter * f);
+int init_filters(tv_filters * filters);
+int add_filter_to_filters(tv_filters * filters, tv_filter * filter);
+int clear_filters(tv_filters * filters);
+int union_filter(tv_filter * f1, tv_filter * f2);
+int intersect_filter(tv_filter * f1, tv_filter * f2);
 
 #endif
