@@ -1,4 +1,4 @@
-/* $Id: acyclic.c,v 1.3 2007/08/08 23:00:58 erg Exp $ $Revision: 1.3 $ */
+/* $Id: acyclic.c,v 1.4 2008/01/09 20:50:35 erg Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -20,6 +20,27 @@
  * Updated by Emden Gansner
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef HAVE_UNISTD_H
+#include	<unistd.h>
+#endif
+#include <stdio.h>
+#ifdef USE_CGRAPH
+#include <stdlib.h>
+#include <cgraph.h>
+typedef struct {
+    Agrec_t h;
+    int mark;
+    int onstack;
+} Agnodeinfo_t;
+
+#define ND_mark(n) (((Agnodeinfo_t*)((n)->base.data))->mark)
+#define ND_onstack(n) (((Agnodeinfo_t*)((n)->base.data))->onstack)
+#define graphName(g) (agnameof(g))
+#else
 typedef char Agraphinfo_t;
 typedef char Agedgeinfo_t;
 typedef struct {
@@ -29,16 +50,12 @@ typedef struct {
 
 #define ND_mark(n) (n)->u.mark
 #define ND_onstack(n) (n)->u.onstack
+#define aghead(e) ((e)->head)
+#define agtail(e) ((e)->tail)
+#define graphName(g) ((g)->name)
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#ifdef HAVE_UNISTD_H
-#include	<unistd.h>
-#endif
-#include <stdio.h>
 #include <graph.h>
+#endif
 
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
@@ -52,8 +69,25 @@ static int doWrite = 1;
 static int Verbose;
 static char *cmd;
 
+/* addRevEdge:
+ * Add a reversed version of e. The new edge has the same key.
+ * We also copy the attributes, reversing the roles of head and 
+ * tail ports.
+ * This assumes we've already checked that such an edge does not exist.
+ */
 static void addRevEdge(Agraph_t * g, Agedge_t * e)
 {
+#ifdef USE_CGRAPH
+    Agsym_t* sym;
+    Agedge_t* f = agedge (g, aghead(e), agtail(e), agnameof(e), 1);
+
+    agcopyattr (e, f);
+
+    sym = agattr (g, AGEDGE, TAILPORT_ID, 0);
+    if (sym) agsafeset (f, HEADPORT_ID, agxget (e, sym), "");
+    sym = agattr (g, AGEDGE, HEADPORT_ID, 0);
+    if (sym) agsafeset (f, TAILPORT_ID, agxget (e, sym), "");
+#else
     Agedge_t *reve;
     char *tmps;
     char **attrs;
@@ -72,6 +106,7 @@ static void addRevEdge(Agraph_t * g, Agedge_t * e)
     tmps = reve->attr[1];
     reve->attr[1] = reve->attr[2];
     reve->attr[2] = tmps;
+#endif
 }
 
 static int dfs(Agraph_t * g, Agnode_t * t, int hasCycle)
@@ -84,15 +119,26 @@ static int dfs(Agraph_t * g, Agnode_t * t, int hasCycle)
     ND_onstack(t) = 1;
     for (e = agfstout(g, t); e; e = f) {
 	f = agnxtout(g, e);
-	if (e->tail == e->head)
+	if (agtail(e) == aghead(e))
 	    continue;
-	h = e->head;
+	h = aghead(e);
 	if (ND_onstack(h)) {
+#ifdef USE_CGRAPH
+	    if (agisstrict(g)) {
+		if (agedge(g, h, t, 0, 0) == 0)
+		    addRevEdge(g, e);
+	    } else {
+		char* key = agnameof (e);
+		if (!key || (agedge(g, h, t, key, 0) == 0))
+		    addRevEdge(g, e);
+	    }
+#else
 	    if (AG_IS_STRICT(g)) {
 		if (agfindedge(g, h, t) == 0)
 		    addRevEdge(g, e);
 	    } else
 		addRevEdge(g, e);
+#endif
 	    agdelete(g, e);
 	    hasCycle = 1;
 	} else if (ND_mark(h) == 0)
@@ -137,7 +183,9 @@ static void init(int argc, char *argv[])
     int c;
 
     cmd = argv[0];
+#ifndef USE_CGRAPH
     aginit();
+#endif
 
     while ((c = getopt(argc, argv, ":vno:?")) != -1)
 	switch (c) {
@@ -182,8 +230,14 @@ int main(int argc, char *argv[])
 
     init(argc, argv);
 
+#ifdef USE_CGRAPH
+    if ((g = agread(inFile,  (Agdisc_t *) 0)) != 0) {
+	if (agisdirected (g)) {
+	    aginit(g, AGNODE, "info", sizeof(Agnodeinfo_t), TRUE);
+#else
     if ((g = agread(inFile)) != 0) {
 	if (AG_IS_DIRECTED(g)) {
+#endif
 	    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 		if (ND_mark(n) == 0)
 		    rv |= dfs(g, n, 0);
@@ -194,14 +248,14 @@ int main(int argc, char *argv[])
 	    }
 	    if (Verbose) {
 		if (rv)
-		    fprintf(stderr, "Graph %s has cycles\n", g->name);
+		    fprintf(stderr, "Graph %s has cycles\n", graphName(g));
 		else
-		    fprintf(stderr, "Graph %s is acyclic\n", g->name);
+		    fprintf(stderr, "Graph %s is acyclic\n", graphName(g));
 	    }
 	} else {
 	    rv = 2;
 	    if (Verbose)
-		fprintf(stderr, "Graph %s is undirected\n", g->name);
+		fprintf(stderr, "Graph %s is undirected\n", graphName(g));
 	}
 	exit(rv);
     } else
