@@ -1,4 +1,4 @@
-/* $Id: bcomps.c,v 1.4 2007/08/08 23:00:58 erg Exp $ $Revision: 1.4 $ */
+/* $Id: bcomps.c,v 1.5 2008/01/09 20:50:35 erg Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -33,6 +33,33 @@
 #include "compat_getopt.h"
 #endif
 
+#ifdef USE_CGRAPH
+#include <stdlib.h>
+#include <cgraph.h>
+
+typedef struct {
+    Agrec_t h;
+    Agraph_t *next;
+} Agraphinfo_t;
+
+typedef struct {
+    Agrec_t h;
+    Agedge_t *next;
+} Agedgeinfo_t;
+
+typedef struct {
+    Agrec_t h;
+    int low;
+    int val;
+    int isCut;
+} Agnodeinfo_t;
+
+#define Low(n)  (((Agnodeinfo_t*)(n->base.data))->low)
+#define Cut(n)  (((Agnodeinfo_t*)(n->base.data))->isCut)
+#define N(n)  (((Agnodeinfo_t*)(n->base.data))->val)
+#define NEXT(e)  (((Agedgeinfo_t*)(e->base.data))->next)
+#define NEXTBLK(g)  (((Agraphinfo_t*)(g->base.data))->next)
+#else
 typedef struct {
     struct Agraph_t *next;
 } Agraphinfo_t;
@@ -48,7 +75,6 @@ typedef struct {
 } Agnodeinfo_t;
 
 #include <graph.h>
-#include <ingraphs.h>
 
 #define Low(n) ((n)->u.low)
 #define Cut(n) ((n)->u.isCut)
@@ -56,6 +82,12 @@ typedef struct {
 #define NEXT(e) ((e)->u.next)
 #define NEXTBLK(g) ((g)->u.next)
 
+#define aghead(e) ((e)->head)
+#define agtail(e) ((e)->tail)
+#define agnameof(g) ((g)->name)
+#endif
+#include <ingraphs.h>
+
 #define min(a,b) ((a) < (b) ? (a) :  (b))
 
 char **Files;
@@ -171,7 +203,12 @@ static Agraph_t *mkBlock(Agraph_t * g, bcstate * stp)
     Agraph_t *sg;
 
     stp->nComp++;
+#ifdef USE_CGRAPH
+    sg = agsubg(g, blockName(agnameof(g), stp->nComp), 1);
+    agbindrec(sg, "info", sizeof(Agraphinfo_t), TRUE);
+#else
     sg = agsubg(g, blockName(g->name, stp->nComp));
+#endif
     NEXTBLK(sg) = stp->blks;
     stp->blks = sg;
     return sg;
@@ -188,8 +225,8 @@ dfs(Agraph_t * g, Agnode_t * u, bcstate * stp, Agnode_t * parent)
     stp->count++;
     Low(u) = N(u) = stp->count;
     for (e = agfstedge(g, u); e; e = agnxtedge(g, e, u)) {
-	if ((v = e->head) == u)
-	    v = e->tail;
+	if ((v = aghead(e)) == u)
+	    v = agtail(e);
 	if (v == u)
 	    continue;
 	if (N(v) == 0) {
@@ -201,8 +238,13 @@ dfs(Agraph_t * g, Agnode_t * u, bcstate * stp, Agnode_t * parent)
 		sg = mkBlock(g, stp);
 		do {
 		    ep = pop(&stp->stk);
+#ifdef USE_CGRAPH
+		    agsubnode(sg, aghead(ep), 1);
+		    agsubnode(sg, agtail(ep), 1);
+#else
 		    aginsert(sg, ep->head);
 		    aginsert(sg, ep->tail);
+#endif
 		} while (ep != e);
 	    }
 	} else if (parent != v) {
@@ -220,8 +262,13 @@ static void nodeInduce(Agraph_t * g, Agraph_t * eg)
 
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	for (e = agfstout(eg, n); e; e = agnxtout(eg, e)) {
+#ifdef USE_CGRAPH
+	    if (agsubnode(g, aghead(e), 0)) {
+		agsubedge(g, e, 1);
+#else
 	    if (agcontains(g, e->head)) {
 		aginsert(g, e);
+#endif
 	    }
 	}
     }
@@ -233,11 +280,20 @@ static void addCutPts(Agraph_t * tree, Agraph_t * blk)
     Agnode_t *bn;
     Agnode_t *cn;
 
-    bn = agnode(tree, blk->name);
+#ifdef USE_CGRAPH
+    bn = agnode(tree, agnameof(blk), 1);
+#else
+    bn = agnode(tree, agnameof(blk));
+#endif
     for (n = agfstnode(blk); n; n = agnxtnode(blk, n)) {
 	if (Cut(n)) {
+#ifdef USE_CGRAPH
+	    cn = agnode(tree, agnameof(n), 1);
+	    agedge(tree, bn, cn, 0, 1);
+#else
 	    cn = agnode(tree, n->name);
 	    agedge(tree, bn, cn);
+#endif
 	}
     }
 }
@@ -250,6 +306,12 @@ static int process(Agraph_t * g, int gcnt)
     Agraph_t *tree;
     int bcnt;
 
+#ifdef USE_CGRAPH
+    aginit(g, AGNODE, "info", sizeof(Agnodeinfo_t), TRUE);
+    aginit(g, AGEDGE, "info", sizeof(Agedgeinfo_t), TRUE);
+    aginit(g, AGRAPH, "info", sizeof(Agraphinfo_t), TRUE);
+#endif
+
     state.count = 0;
     state.nComp = 0;
     state.stk = 0;
@@ -270,7 +332,11 @@ static int process(Agraph_t * g, int gcnt)
     } else
 	gwrite(g, gcnt, 0);
     if (doTree) {
+#ifdef USE_CGRAPH
+	tree = agopen("blkcut_tree", Agstrictundirected, 0);
+#else
 	tree = agopen("blkcut_tree", AGFLAG_STRICT);
+#endif
 	for (blk = state.blks; blk; blk = NEXTBLK(blk))
 	    addCutPts(tree, blk);
 	gwrite(tree, gcnt, -1);
@@ -284,7 +350,7 @@ static int process(Agraph_t * g, int gcnt)
 	for (n = agfstnode(g); n; n = agnxtnode(g, n))
 	    if (Cut(n))
 		cuts++;
-	fprintf(stderr, "%s: %d blocks %d cutpoints\n", g->name, bcnt,
+	fprintf(stderr, "%s: %d blocks %d cutpoints\n", agnameof(g), bcnt,
 		cuts);
     }
     if (state.blks && NEXTBLK(state.blks))
@@ -330,7 +396,9 @@ static void init(int argc, char *argv[])
 {
     int c;
 
+#ifndef USE_CGRAPH
     aginit();
+#endif
     while ((c = getopt(argc, argv, ":o:xstv?")) != -1) {
 	switch (c) {
 	case 'o':
@@ -366,6 +434,13 @@ static void init(int argc, char *argv[])
 	Files = argv;
 }
 
+#ifdef USE_CGRAPH
+static Agraph_t *gread(FILE * fp)
+{
+  return agread(fp, (Agdisc_t *) 0);
+}
+#endif
+
 int main(int argc, char *argv[])
 {
     Agraph_t *g;
@@ -374,7 +449,11 @@ int main(int argc, char *argv[])
     int gcnt = 0;
 
     init(argc, argv);
+#ifdef USE_CGRAPH
+    newIngraph(&ig, Files, gread);
+#else
     newIngraph(&ig, Files, agread);
+#endif
 
     while ((g = nextGraph(&ig)) != 0) {
 	r |= process(g, gcnt);
