@@ -1,4 +1,4 @@
-/* $Id: gvpack.c,v 1.10 2006/06/19 17:55:05 ellson Exp $ $Revision: 1.10 $ */
+/* $Id: gvpack.c,v 1.14 2007/08/08 23:00:58 erg Exp $ $Revision: 1.14 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -30,6 +30,7 @@
 #endif
 
 #include <assert.h>
+#include <gvc.h>
 #include <render.h>
 #include <neatoprocs.h>
 #include <ingraphs.h>
@@ -67,7 +68,7 @@ typedef struct {
 } pair_t;
 
 static int margin = 8;		/* Default margin in packing */
-static bool doSplines = TRUE;	/* Use edges in packing */
+static boolean doSplines = TRUE;	/* Use edges in packing */
 static pack_mode packMode = l_clust;	/* Default packing mode - use clusters */
 static int verbose = 0;
 static char **myFiles = 0;
@@ -169,7 +170,7 @@ static void init(int argc, char *argv[])
     int c;
 
     aginit();
-    while ((c = getopt(argc, argv, ":ngvum:o:G:")) != -1) {
+    while ((c = getopt(argc, argv, ":ngvum:o:G:?")) != -1) {
 	switch (c) {
 	case 'n':
 	    packMode = l_node;
@@ -244,7 +245,7 @@ static void init_node_edge(Agraph_t * g)
  * libcommon. If fill is true, we use init_nop (neato -n) to
  * read in attributes relevant to the layout.
  */
-static void init_graph(Agraph_t * g, bool fill)
+static void init_graph(Agraph_t * g, boolean fill)
 {
     int d;
 
@@ -576,7 +577,7 @@ static Dtdisc_t pairdisc = {
  * Create and return a new graph which is the logical union
  * of the graphs gs. 
  */
-static Agraph_t *cloneGraph(Agraph_t ** gs, int cnt)
+static Agraph_t *cloneGraph(Agraph_t ** gs, int cnt, GVC_t * gvc)
 {
     Agraph_t *root;
     Agraph_t *g;
@@ -588,11 +589,12 @@ static Agraph_t *cloneGraph(Agraph_t ** gs, int cnt)
     Dt_t *nnames;		/* dict of used node names */
     Agsym_t *G_bb;
     Agsym_t *rv;
-    bool doWarn = TRUE;
+    boolean doWarn = TRUE;
 
     if (verbose)
 	fprintf(stderr, "Creating clone graph\n");
     root = agopen("root", kind);
+    GD_gvc(root) = gvc;
     initAttrs(root, gs, cnt);
     G_bb = agfindattr(root, "bb");
     if (DOPACK) assert(G_bb);
@@ -668,7 +670,7 @@ static Agraph_t *cloneGraph(Agraph_t ** gs, int cnt)
  * combined graph will be strict; other, the combined graph will
  * be non-strict.
  */
-static Agraph_t **readGraphs(int *cp)
+static Agraph_t **readGraphs(int *cp, GVC_t* gvc)
 {
     Agraph_t *g;
     Agraph_t **gs = 0;
@@ -682,6 +684,7 @@ static Agraph_t **readGraphs(int *cp)
 
     newIngraph(&ig, myFiles, agread);
     while ((g = nextGraph(&ig)) != 0) {
+	GD_gvc(g) = gvc;
 	if (verbose)
 	    fprintf(stderr, "Reading graph %s\n", g->name);
 	if (cnt >= sz) {
@@ -766,10 +769,12 @@ int main(int argc, char *argv[])
     int cnt;
     pack_info pinfo;
     box bb;
+    GVC_t * gvc;
 
     init(argc, argv);
 
-    gs = readGraphs(&cnt);
+    gvc = gvNEWcontext(Info, gvUsername());
+    gs = readGraphs(&cnt, gvc);
     if (cnt == 0)
 	exit(0);
 
@@ -786,7 +791,7 @@ int main(int argc, char *argv[])
     }
 
     /* create union graph and copy attributes */
-    g = cloneGraph(gs, cnt);
+    g = cloneGraph(gs, cnt, gvc);
 
     /* compute new top-level bb and set */
     if (DOPACK) {
