@@ -1,4 +1,4 @@
-/* $Id: gxl2dot.c,v 1.3 2006/04/24 17:04:55 erg Exp $ $Revision: 1.3 $ */
+/* $Id: gxl2dot.c,v 1.4 2008/01/09 20:50:35 erg Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -16,7 +16,9 @@
 
 
 #include    <convert.h>
+#ifndef USE_CGRAPH
 #include    "aghdr.h"
+#endif
 #include    "agxbuf.h"
 #ifdef HAVE_LIBEXPAT
 #include    <expat.h>
@@ -243,7 +245,11 @@ static Agedge_t *bind_edge(const char *tail, const char *head)
 
     tailNode = agnode(G, (char *) tail, 1);
     headNode = agnode(G, (char *) head, 1);
+#ifdef USE_CGRAPH
+    E = agedge(G, tailNode, headNode, key, 1);
+#else
     E = agedge(tailNode, headNode, key, 1);
+#endif
     return E;
 }
 
