@@ -1,4 +1,4 @@
-/* $Id: sccmap.c,v 1.4 2007/08/08 23:00:58 erg Exp $ $Revision: 1.4 $ */
+/* $Id: sccmap.c,v 1.5 2008/01/09 20:50:35 erg Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -34,7 +34,11 @@
 #ifdef HAVE_UNISTD_H
 #include	<unistd.h>
 #endif
+#ifdef USE_CGRAPH
+#include <cgraph.h>
+#else
 #include <agraph.h>
+#endif
 #include <ingraphs.h>
 
 #ifdef HAVE_GETOPT_H
@@ -144,6 +148,29 @@ int Verbose;
 char *CmdName;
 char **Files;
 
+#ifdef USE_CGRAPH
+static void nodeInduce(Agraph_t * g, Agraph_t* map)
+{
+    Agnode_t *n;
+    Agedge_t *e;
+    Agraph_t* rootg = agroot (g);
+
+    
+    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+	for (e = agfstout(rootg, n); e; e = agnxtout(rootg, e)) {
+	    if (agsubnode(g, aghead(e), FALSE))
+		agsubedge(g, e, TRUE);
+	    else {
+		Agraph_t* tscc = getscc(agtail(e));
+		Agraph_t* hscc = getscc(aghead(e));
+		if (tscc && hscc)
+		    agedge(map, getrep(tscc),
+			   getrep(hscc), NIL(char *), TRUE);
+	    }
+	}
+    }
+}
+#else
 static void nodeInduce(Agraph_t * g)
 {
     Agnode_t *n, *rootn;
@@ -162,6 +189,7 @@ static void nodeInduce(Agraph_t * g)
 	}
     }
 }
+#endif
 
 static int visit(Agnode_t * n, Agraph_t * map, Stack * sp, sccstate * st)
 {
@@ -174,7 +202,11 @@ static int visit(Agnode_t * n, Agraph_t * map, Stack * sp, sccstate * st)
     setval(n, min);
     push(sp, n);
 
+#ifdef USE_CGRAPH
+    for (e = agfstout(n->root, n); e; e = agnxtout(n->root, e)) {
+#else
     for (e = agfstout(n); e; e = agnxtout(e)) {
+#endif
 	t = aghead(e);
 	if (getval(t) == 0)
 	    m = visit(t, map, sp, st);
@@ -202,7 +234,11 @@ static int visit(Agnode_t * n, Agraph_t * map, Stack * sp, sccstate * st)
 		setscc(t, subg);
 		st->N_nodes_in_nontriv_SCC++;
 	    } while (t != n);
+#ifdef USE_CGRAPH
+	    nodeInduce(subg, map);
+#else
 	    nodeInduce(subg);
+#endif
 	    if (!Silent)
 		agwrite(subg, stdout);
 	}
@@ -216,7 +252,11 @@ static int label(Agnode_t * n, int nodecnt, int *edgecnt)
 
     setval(n, 1);
     nodecnt++;
+#ifdef USE_CGRAPH
+    for (e = agfstedge(n->root, n); e; e = agnxtedge(n->root, e, n)) {
+#else
     for (e = agfstedge(n); e; e = agnxtedge(e, n)) {
+#endif
 	(*edgecnt) += 1;
 	if (e->node == n)
 	    e = agopp(e);
@@ -237,7 +277,11 @@ countComponents(Agraph_t * g, int *max_degree, float *nontree_frac)
     int n_nodes;
     Agnode_t *n;
 
+#ifdef USE_CGRAPH
+    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+#else
     for (n = agfstnode(g); n; n = agnxtnode(n)) {
+#endif
 	if (!getval(n)) {
 	    nc++;
 	    n_edges = 0;
@@ -248,8 +292,13 @@ countComponents(Agraph_t * g, int *max_degree, float *nontree_frac)
     }
     if (max_degree) {
 	int maxd = 0;
+#ifdef USE_CGRAPH
+	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+	    deg = agdegree(g, n, TRUE, TRUE);
+#else
 	for (n = agfstnode(g); n; n = agnxtnode(n)) {
 	    deg = agdegree(n, TRUE, TRUE);
+#endif
 	    if (maxd < deg)
 		maxd = deg;
 	    setval(n, 0);
@@ -285,7 +334,11 @@ static void process(Agraph_t * G)
 
     initStack(&stack, agnnodes(G) + 1);
     map = agopen("scc_map", Agdirected, (Agdisc_t *) 0);
+#ifdef USE_CGRAPH
+    for (n = agfstnode(G); n; n = agnxtnode(G, n))
+#else
     for (n = agfstnode(G); n; n = agnxtnode(n))
+#endif
 	if (getval(n) == 0)
 	    visit(n, map, &stack, &state);
     freeStack(&stack);
