@@ -1,4 +1,4 @@
-/* $Id: unflatten.c,v 1.3 2007/08/08 23:00:58 erg Exp $ $Revision: 1.3 $ */
+/* $Id: unflatten.c,v 1.4 2008/01/09 20:50:35 erg Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -29,7 +29,13 @@
 #ifdef HAVE_UNISTD_H
 #include	<unistd.h>
 #endif
+#ifdef USE_CGRAPH
+#include    <cgraph.h>
+#define degreeOf(n,I,O) (agdegree(n->root, n, I, O)) 
+#else
 #include    <agraph.h>
+#define degreeOf(n,I,O) (agdegree(n, I, O)) 
+#endif
 #include    <ingraphs.h>
 
 #ifdef HAVE_GETOPT_H
@@ -48,13 +54,13 @@ static char *cmd;
 
 static int isleaf(Agnode_t * n)
 {
-    return (agdegree(n, TRUE, TRUE) == 1);
+    return (degreeOf(n, TRUE, TRUE) == 1);
 }
 
 static int ischainnode(Agnode_t * n)
 {
-    return ((agdegree(n, TRUE, FALSE) == 1)
-	    && agdegree(n, FALSE, TRUE) == 1);
+    return ((degreeOf(n, TRUE, FALSE) == 1)
+	    && degreeOf(n, FALSE, TRUE) == 1);
 }
 
 static void adjustlen(Agedge_t * e, Agsym_t * sym, int newlen)
@@ -81,13 +87,21 @@ static void transform(Agraph_t * g)
     m_ix = bindedgeattr(g, "minlen");
     s_ix = bindedgeattr(g, "style");
 
+#ifdef USE_CGRAPH
+    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+#else
     for (n = agfstnode(g); n; n = agnxtnode(n)) {
-	d = agdegree(n, TRUE, TRUE);
+#endif
+	d = degreeOf(n, TRUE, TRUE);
 	if (d == 0) {
 	    if (ChainLimit < 1)
 		continue;
 	    if (ChainNode) {
+#ifdef USE_CGRAPH
+		e = agedge(g, ChainNode, n, "", TRUE);
+#else
 		e = agedge(ChainNode, n, "", TRUE);
+#endif
 		agxset(e, s_ix, "invis");
 		ChainSize++;
 		if (ChainSize < ChainLimit)
@@ -102,7 +116,11 @@ static void transform(Agraph_t * g)
 	    if (MaxMinlen < 1)
 		continue;
 	    cnt = 0;
+#ifdef USE_CGRAPH
+	    for (e = agfstin(g, n); e; e = agnxtin(g, e)) {
+#else
 	    for (e = agfstin(n); e; e = agnxtin(e)) {
+#endif
 		if (isleaf(agtail(e))) {
 		    str = agxget(e, m_ix);
 		    if (str[0] == 0) {
@@ -113,7 +131,11 @@ static void transform(Agraph_t * g)
 	    }
 
 	    cnt = 0;
+#ifdef USE_CGRAPH
+	    for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
+#else
 	    for (e = agfstout(n); e; e = agnxtout(e)) {
+#endif
 		if (isleaf(e->node) || (Do_fans && ischainnode(e->node))) {
 		    str = agxget(e, m_ix);
 		    if (str[0] == 0)
