@@ -1,5 +1,7 @@
 #ifndef COMPAT_H
 #define COMPAT_H
+#ifdef HAVE_CONFIG_H
+#include "config.h"
 #ifndef HAVE_STRCASECMP
 extern int strcasecmp(const char*, const char*);
 #endif
@@ -7,3 +9,4 @@ extern int strcasecmp(const char*, const char*);
 extern int strncasecmp(const char*, const char*, unsigned int);
 #endif
 #endif
+#endif
