@@ -1,4 +1,4 @@
-/* $Id: diffimg.c,v 1.12 2007/10/19 17:33:50 ellson Exp $ $Revision: 1.12 $ */
+/* $Id: diffimg.c,v 1.13 2008/02/22 14:21:42 glenlow Exp $ $Revision: 1.13 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -36,7 +36,14 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#ifdef WIN32
+#define EX_USAGE		64
+#define EX_DATAERR		65
+#define EX_NOINPUT		66
+#define EX_UNAVAILABLE	69
+#else
 #include <sysexits.h>
+#endif
 #include <gd.h>
 #if defined HAVE_STDBOOL_H && ! defined __cplusplus
 #include <stdbool.h>
