@@ -1,4 +1,4 @@
-/* $Id: dot.c,v 1.3 2005/07/27 19:55:28 ellson Exp $ $Revision: 1.3 $ */
+/* $Id: dot.c,v 1.4 2006/04/29 01:10:02 ellson Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -24,7 +24,7 @@ int main(int argc, char **argv)
     gvc = gvContext();
     gvParseArgs(gvc, argc, argv);
 
-    while ((g = next_input_graph())) {
+    while ((g = gvNextInputGraph(gvc))) {
 	if (prev) {
 	    gvFreeLayout(gvc, prev);
 	    agclose(prev);
