@@ -1,4 +1,4 @@
-/* $Id: attr.c,v 1.2 2006/07/08 17:33:49 ellson Exp $ $Revision: 1.2 $ */
+/* $Id: attr.c,v 1.3 2008/03/08 18:26:30 ellson Exp $ $Revision: 1.3 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -28,9 +28,9 @@
 static void freesym(Dict_t * d, Void_t * obj, Dtdisc_t * disc);
 
 Dtdisc_t AgDataDictDisc = {
-    (int) offsetof(Agsym_t, name),	/* use symbol name as key */
+    offsetof(Agsym_t, name),	/* use symbol name as key */
     -1,
-    (int) offsetof(Agsym_t, link),
+    offsetof(Agsym_t, link),
     NIL(Dtmake_f),
     freesym,
     NIL(Dtcompar_f),
