@@ -1,4 +1,4 @@
-/* $Id: flatten.c,v 1.3 2006/07/18 18:07:44 ellson Exp $ $Revision: 1.3 $ */
+/* $Id: flatten.c,v 1.4 2008/04/23 18:21:41 ellson Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -26,13 +26,17 @@ void agflatten_elist(Dict_t * d, Dtlink_t ** lptr)
 
 void agflatten_edges(Agraph_t * g, Agnode_t * n)
 {
-    Agedge_t **tmp;
 
-    tmp = &(n->out); /* avoiding - "dereferencing type-punned pointer will break strict-aliasing rules" */
+    union {
+    	Dtlink_t **dtlink;
+    	Agedge_t **agedge;
+	} out, in;
+
+    out.agedge = & (n->out);
+    in.agedge = & (n->in);
+    agflatten_elist(g->e_seq, out.dtlink);
+    agflatten_elist(g->e_seq, in.dtlink);
 
-    agflatten_elist(g->e_seq, (Dtlink_t **) tmp);
-    tmp = &(n->in);
-    agflatten_elist(g->e_seq, (Dtlink_t **) tmp);
 }
 
 void agflatten(Agraph_t * g, int flag)
