@@ -1,4 +1,4 @@
-/* $Id: error.c,v 1.1.1.1 2004/12/23 04:04:21 ellson Exp $ $Revision: 1.1.1.1 $ */
+/* $Id: error.c,v 1.2 2007/07/17 21:47:46 erg Exp $ $Revision: 1.2 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,6 +18,14 @@
  * standalone mini error implementation
  */
 
+#ifdef WIN32
+#include <config.h>
+
+#ifdef GVDLL
+#define _BLD_sfio 1
+#endif
+#endif
+
 #include <ast.h>
 #include <error.h>
 #include <string.h>
@@ -25,6 +33,15 @@
 
 Error_info_t error_info;
 
+void setErrorLine (int line) { error_info.line = line; }
+void setErrorFileLine (char* src, int line) {
+    error_info.file = src;
+    error_info.line = line;
+}
+void setErrorId (char* id) { error_info.id = id; }
+void setErrorErrors (int errors) { error_info.errors = errors; }
+int  getErrorErrors () { return error_info.errors; }
+
 void errorv(const char *id, int level, va_list ap)
 {
     char *s;
