@@ -1,4 +1,4 @@
-/* $Id: strton.c,v 1.1.1.1 2004/12/23 04:04:22 ellson Exp $ $Revision: 1.1.1.1 $ */
+/* $Id: strton.c,v 1.2 2007/05/08 18:24:38 erg Exp $ $Revision: 1.2 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -56,6 +56,9 @@
 
 #include <ctype.h>
 
+/* For graphviz, only unthreaded */
+#define vt_threaded 0
+
 #include "sfhdr.h"
 
 #define QL		01
