@@ -1,4 +1,4 @@
-/* $Id: agxbuf.c,v 1.1 2007/10/25 20:27:57 north Exp $ $Revision: 1.1 $ */
+/* $Id: agxbuf.c,v 1.2 2008/03/03 23:03:40 arif Exp $ $Revision: 1.2 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -53,7 +53,7 @@ int agxbmore(agxbuf * xb, unsigned int ssz)
 
     size = xb->eptr - xb->buf;
     nsize = 2 * size;
-    if (size + ssz > nsize)
+    if (size + (int)ssz > nsize)
 	nsize = size + ssz;
     cnt = xb->ptr - xb->buf;
     if (xb->dyna) {
