@@ -1,4 +1,4 @@
-/* $Id: write.c,v 1.4 2008/03/04 17:54:53 arif Exp $ $Revision: 1.4 $ */
+/* $Id: write.c,v 1.8 2008/04/30 15:18:03 erg Exp $ $Revision: 1.8 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -21,12 +21,6 @@
 #define EMPTY(s)		((s == 0) || (s)[0] == '\0')
 #define MAX(a,b)     ((a)>(b)?(a):(b))
 
-#ifdef WIN32
-extern int strcasecmp(const char *s1, const char *s2);
-extern int strncasecmp(const char *s1, const char *s2, unsigned int n);
-#endif
-
-
 typedef void iochan_t;
 
 static void ioput(Agraph_t * g, iochan_t * ofile, char *str)
@@ -46,6 +40,23 @@ static void indent(Agraph_t * g, iochan_t * ofile)
 	ioput(g, ofile, "\t");
 }
 
+#ifndef HAVE_STRCASECMP
+
+#include <string.h>
+
+static int strcasecmp(const char *s1, const char *s2)
+{
+    while ((*s1 != '\0')
+	   && (tolower(*(unsigned char *) s1) ==
+	       tolower(*(unsigned char *) s2))) {
+	s1++;
+	s2++;
+    }
+
+    return tolower(*(unsigned char *) s1) - tolower(*(unsigned char *) s2);
+}
+#endif
+
 /* _agstrcanon:
  * Canonicalize ordinary strings. 
  * Assumes buf is large enough to hold output.
@@ -275,20 +286,10 @@ static void write_trl(Agraph_t * g, iochan_t * ofile)
     ioput(g, ofile, "}\n");
 }
 
-static int localsize(Dict_t * d)
-{
-    int rv;
-    Dict_t *view;
-    view = dtview(d, NIL(Dict_t *));
-    rv = dtsize(d);
-    dtview(d, view);
-    return rv;
-}
-
 static int irrelevant_subgraph(Agraph_t * g)
 {
     int i, n;
-    Agattr_t *sdata, *pdata;
+    Agattr_t *sdata, *pdata, *rdata;
     Agdatadict_t *dd;
 
     char *name;
@@ -297,14 +298,15 @@ static int irrelevant_subgraph(Agraph_t * g)
     if (name && name[0] != LOCALNAMEPREFIX)
 	return FALSE;
     if ((sdata = agattrrec(g)) && (pdata = agattrrec(agparent(g)))) {
-	n = dtsize(sdata->dict);
+	rdata = agattrrec(agroot(g));
+	n = dtsize(rdata->dict);
 	for (i = 0; i < n; i++)
 	    if (sdata->str[i] && pdata->str[i]
 		&& strcmp(sdata->str[i], pdata->str[i]))
 		return FALSE;
     }
     dd = agdatadict(g);
-    if ((localsize(dd->dict.n) > 0) || (localsize(dd->dict.e) > 0))
+    if ((dtsize(dd->dict.n) > 0) || (dtsize(dd->dict.e) > 0))
 	return FALSE;
     return TRUE;
 }
