@@ -1,4 +1,4 @@
-/* $Id: arith.h,v 1.8 2006/07/08 20:42:53 ellson Exp $ $Revision: 1.8 $ */
+/* $Id: arith.h,v 1.12 2008/05/15 14:51:09 ellson Exp $ $Revision: 1.12 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -24,17 +24,13 @@
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE 1
 #endif
-#ifdef HAVE_LIMITS_H
+
 #include <limits.h>
-#else
 #ifdef HAVE_VALUES_H
 #include <values.h>
 #endif
-#endif
 #include <math.h>
 
-#include "logic.h"
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -83,12 +79,12 @@ extern "C" {
 #define M_PI		3.14159265358979323846
 #endif
 
-#ifndef PI
-#define PI		M_PI
+#ifndef SQRT2
+#define SQRT2		1.41421356237309504880
 #endif
 
 #define ROUND(f)        ((f>=0)?(int)(f + .5):(int)(f - .5))
-#define RADIANS(deg)	((deg)/180.0 * PI)
+#define RADIANS(deg)	((deg)/180.0 * M_PI)
 #define DEGREES(rad)	((rad)/M_PI * 180.0)
 
 #define SQR(a) ((a) * (a))
