@@ -1,4 +1,4 @@
-hsvrgbacolor_t color_lib[] = {
+static hsvrgbacolor_t color_lib[] = {
 {"/accent3/1",85,93,201,127,201,127,255},
 {"/accent3/2",187,45,212,190,174,212,255},
 {"/accent3/3",20,119,253,253,192,134,255},
@@ -2059,6 +2059,7 @@ hsvrgbacolor_t color_lib[] = {
 {"indianred3",0,149,205,205,85,85,255},
 {"indianred4",0,148,139,139,58,58,255},
 {"indigo",194,255,130,75,0,130,255},
+{"invis",42,0,255,255,255,254,0},
 {"ivory",42,15,255,255,255,240,255},
 {"ivory1",42,15,255,255,255,240,255},
 {"ivory2",42,15,238,238,238,224,255},
@@ -2173,6 +2174,7 @@ hsvrgbacolor_t color_lib[] = {
 {"navajowhite4",25,82,139,139,121,94,255},
 {"navy",170,255,128,0,0,128,255},
 {"navyblue",170,255,128,0,0,128,255},
+{"none",42,0,255,255,255,254,0},
 {"oldlace",27,23,253,253,245,230,255},
 {"olivedrab",56,192,142,107,142,35,255},
 {"olivedrab1",56,193,255,192,255,62,255},
