@@ -1,4 +1,4 @@
-/* $Id: diagen.c,v 1.24 2007/09/24 08:22:20 ellson Exp $ $Revision: 1.24 $ */
+/* $Id: diagen.c,v 1.25 2008/04/23 18:05:06 ellson Exp $ $Revision: 1.25 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -245,7 +245,7 @@ static pointf diapt(point p)
 
 static void dia_grstyle(context_t * cp)
 {
-    if (cp->pencolor != DEFAULT_COLOR) {
+    if (strcmp(cp->pencolor, DEFAULT_COLOR)) {
 	dia_fputs("      <dia:attribute name=\"border_color\">\n");
 	dia_printf("        <dia:color val=\"%s\"/>\n",
 		   dia_resolve_color(cp->pencolor));
