@@ -1,4 +1,4 @@
-/* $Id: emit.c,v 1.240 2008/02/29 22:00:16 ellson Exp $ $Revision: 1.240 $ */
+/* $Id: emit.c,v 1.249 2008/04/25 20:05:39 ellson Exp $ $Revision: 1.249 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -707,6 +707,16 @@ static void init_job_pagination(GVJ_t * job, graph_t *g)
     /* size of one page in graph units */
     job->pageSize.x = imageSize.x / job->zoom;
     job->pageSize.y = imageSize.y / job->zoom;
+
+    /* pageBoundingBox in device units and page orientation */
+    job->pageBoundingBox.LL.x = ROUND(job->canvasBox.LL.x * job->dpi.x / POINTS_PER_INCH);
+    job->pageBoundingBox.LL.y = ROUND(job->canvasBox.LL.y * job->dpi.y / POINTS_PER_INCH);
+    job->pageBoundingBox.UR.x = ROUND(job->canvasBox.UR.x * job->dpi.x / POINTS_PER_INCH);
+    job->pageBoundingBox.UR.y = ROUND(job->canvasBox.UR.y * job->dpi.y / POINTS_PER_INCH);
+    if (job->rotation) {
+	job->pageBoundingBox.LL = exch_xy(job->pageBoundingBox.LL);
+	job->pageBoundingBox.UR = exch_xy(job->pageBoundingBox.UR);
+    }
 }
 
 static void firstpage(GVJ_t *job)
@@ -773,7 +783,8 @@ void emit_background(GVJ_t * job, graph_t *g)
 
     gvrender_set_fillcolor(job, str);
     gvrender_set_pencolor(job, str);
-    gvrender_box(job, job->clip, TRUE);	/* filled */
+    if (!(job->flags & GVRENDER_NO_BG))
+        gvrender_box(job, job->clip, TRUE);	/* filled */
 }
 
 static void setup_page(GVJ_t * job, graph_t * g)
@@ -791,32 +802,24 @@ static void setup_page(GVJ_t * job, graph_t * g)
     job->pageBox.UR.x = job->pageBox.LL.x + job->pageSize.x;
     job->pageBox.UR.y = job->pageBox.LL.y + job->pageSize.y;
 
-    /* pageBoundingBox in device units and page orientation */
-    job->pageBoundingBox.LL.x = ROUND(job->canvasBox.LL.x * job->dpi.x / POINTS_PER_INCH);
-    job->pageBoundingBox.LL.y = ROUND(job->canvasBox.LL.y * job->dpi.y / POINTS_PER_INCH);
-    job->pageBoundingBox.UR.x = ROUND(job->canvasBox.UR.x * job->dpi.x / POINTS_PER_INCH);
-    job->pageBoundingBox.UR.y = ROUND(job->canvasBox.UR.y * job->dpi.y / POINTS_PER_INCH);
-    if (job->rotation) {
-	job->pageBoundingBox.LL = exch_xy(job->pageBoundingBox.LL);
-	job->pageBoundingBox.UR = exch_xy(job->pageBoundingBox.UR);
-    }
-	
     /* maximum boundingBox in device units and page orientation */
     if (job->common->viewNum == 0)
         job->boundingBox = job->pageBoundingBox;
     else
         EXPANDBB(job->boundingBox, job->pageBoundingBox);
 
+#ifdef WITH_CODEGENS
+    job->pageOffset.x = - job->pageSize.x * pagesArrayElem.x;
+    job->pageOffset.y = - job->pageSize.y * pagesArrayElem.y;
+#endif
+    job->clip.LL.x = job->focus.x + job->pageSize.x * (pagesArrayElem.x - pagesArraySize.x / 2.);
+    job->clip.LL.y = job->focus.y + job->pageSize.y * (pagesArrayElem.y - pagesArraySize.y / 2.);
+    job->clip.UR.x = job->clip.LL.x + job->pageSize.x;
+    job->clip.UR.y = job->clip.LL.y + job->pageSize.y;
 
     /* CAUTION - job->translation was difficult to get right. */
     /* Test with and without assymetric margins, e.g: -Gmargin="1,0" */
-    job->pageOffset.x = - job->pageSize.x * pagesArrayElem.x;
-    job->pageOffset.y = - job->pageSize.y * pagesArrayElem.y;
     if (job->rotation) {
-        job->clip.LL.x = job->focus.x - job->pageOffset.x - pagesArraySize.x * job->pageSize.x / 2.;
-        job->clip.UR.y = job->focus.y + job->pageOffset.y + pagesArraySize.y * job->pageSize.y / 2.;
-        job->clip.UR.x = job->clip.LL.x + job->view.x - 2 * job->margin.y / job->zoom;
-        job->clip.LL.y = job->clip.UR.y - job->view.y + 2 * job->margin.x / job->zoom;
 	job->translation.y = - job->clip.UR.y - job->canvasBox.LL.y / job->zoom;
         if ((job->flags & GVRENDER_Y_GOES_DOWN) || (Y_invert))
             job->translation.x = - job->clip.UR.x - job->canvasBox.LL.x / job->zoom;
@@ -824,10 +827,6 @@ static void setup_page(GVJ_t * job, graph_t * g)
             job->translation.x = - job->clip.LL.x + job->canvasBox.LL.x / job->zoom;
     }
     else {
-	job->clip.LL.x = job->focus.x - job->pageOffset.x - pagesArraySize.x * job->pageSize.x / 2.;
-	job->clip.LL.y = job->focus.y - job->pageOffset.y - pagesArraySize.y * job->pageSize.y / 2.;
-        job->clip.UR.x = job->clip.LL.x + job->view.x - 2 * job->margin.x / job->zoom;
-        job->clip.UR.y = job->clip.LL.y + job->view.y - 2 * job->margin.y / job->zoom;
 	/* pre unscale margins to keep them constant under scaling */
         job->translation.x = - job->clip.LL.x + job->canvasBox.LL.x / job->zoom;
         if ((job->flags & GVRENDER_Y_GOES_DOWN) || (Y_invert))
@@ -1067,14 +1066,15 @@ static void emit_begin_node(GVJ_t * job, node_t * n)
                     p = N_NEW(nump, pointf);
                     p[0].x = coord.x;
                     p[0].y = coord.y;
-		    /* ... but vertices contains LL cornet of bb */
-                    p[1].x = coord.x - vertices[peripheries - 1].x;
-                    p[1].y = coord.y - vertices[peripheries - 1].y;
+		    /* even vertices contain LL corner of bb */
+		    /* odd vertices contain UR corner of bb */
+                    p[1].x = coord.x + vertices[2*peripheries - 1].x;
+                    p[1].y = coord.y + vertices[2*peripheries - 1].y;
                 }
                 else { /* ellipse is treated as polygon */
                     obj->url_map_shape= MAP_POLYGON;
-                    p = pEllipse((double)(vertices[peripheries - 1].x),
-                                 (double)(vertices[peripheries - 1].y), nump);
+                    p = pEllipse((double)(vertices[2*peripheries - 1].x),
+                                 (double)(vertices[2*peripheries - 1].y), nump);
                     for (i = 0; i < nump; i++) {
                         p[i].x += coord.x;
                         p[i].y += coord.y;
@@ -1947,7 +1947,7 @@ static void init_job_viewport(GVJ_t * job, graph_t * g)
     Agnode_t *n;
     char *nodename = NULL;
 
-    assert((gvc->bb.LL.x == 0) && (gvc->bb.LL.y == 0));
+//    assert((gvc->bb.LL.x == 0) && (gvc->bb.LL.y == 0));
     P2PF(gvc->bb.UR, UR);
 
     job->bb.LL.x = -job->pad.x;           /* job->bb is bb of graph and padding - graph units */
@@ -1964,9 +1964,9 @@ static void init_job_viewport(GVJ_t * job, graph_t * g)
     Z = 1.0;
     if (GD_drawing(g)->size.x > 0) {	/* graph size was given by user... */
 	P2PF(GD_drawing(g)->size, size);
-	if ((size.x < sz.x) || (size.y < sz.y) /* drawing is too big... */
+	if ((size.x < sz.x) || (size.y < sz.y) /* drawing is too big (in either axi) ... */
 	    || ((GD_drawing(g)->filled) /* or ratio=filled requested and ... */
-		&& (size.x > sz.x) && (size.y > sz.y))) /* drawing is too small... */
+		&& (size.x > sz.x) && (size.y > sz.y))) /* drawing is too small (in both axis) ... */
 	    Z = MIN(size.x/sz.x, size.y/sz.y);
     }
     
@@ -2530,10 +2530,12 @@ static int style_token(char **s, agxbuf * xb)
 static unsigned char outbuf[SMALLBUF];
 static agxbuf ps_xb;
 
+#if 0
 static void cleanup(void)
 {
     agxbfree(&ps_xb);
 }
+#endif
 
 /* parse_style:
  * This is one of the worse internal designs in graphviz.
@@ -2556,7 +2558,9 @@ char **parse_style(char *s)
 
     if (is_first) {
 	agxbinit(&ps_xb, SMALLBUF, outbuf);
+#if 0
 	atexit(cleanup);
+#endif
 	is_first = FALSE;
     }
 
@@ -2615,15 +2619,26 @@ char **parse_style(char *s)
 static boxf bezier_bb(bezier bz)
 {
     int i;
-    point p;
+    point p, p1, p2;
     box bb;
     boxf bbf;
 
     assert(bz.size > 0);
+    assert(bz.size % 3 == 1);
     bb.LL = bb.UR = bz.list[0];
-    for (i = 1; i < bz.size; i++) {
+    for (i = 1; i < bz.size;) {
+	/* take mid-point between two control points for bb calculation */
+	p1=bz.list[i];
+	i++;
+	p2=bz.list[i];
+	i++;
+	p.x = ( p1.x + p2.x ) / 2;
+	p.y = ( p1.y + p2.y ) / 2;
+        EXPANDBP(bb,p);
+
 	p=bz.list[i];
         EXPANDBP(bb,p);
+	i++;
     }
     B2BF(bb, bbf);
     return bbf;
@@ -2697,10 +2712,10 @@ static void init_bb_node(graph_t *g, node_t *n)
 
 static void init_bb(graph_t *g)
 {
-        node_t *n;
+    node_t *n;
 
-	    for (n = agfstnode(g); n; n = agnxtnode(g, n))
-		        init_bb_node(g, n);
+    for (n = agfstnode(g); n; n = agnxtnode(g, n))
+        init_bb_node(g, n);
 }
 
 extern gvevent_key_binding_t gvevent_key_binding[];
