@@ -1,4 +1,4 @@
-/* $Id: fontmetrics.c,v 1.39 2007/11/08 19:42:15 erg Exp $ $Revision: 1.39 $ */
+/* $Id: fontmetrics.c,v 1.42 2008/03/07 19:09:56 ellson Exp $ $Revision: 1.42 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -139,7 +139,6 @@ estimate_textlayout(graph_t *g, textpara_t * para, char **fontpath)
     para->height = para->fontsize * LINESPACING;
     para->yoffset_layout = 0.0;
     para->yoffset_centerline = 0.1 * para->fontsize;
-    para->xshow = NULL;
     para->layout = para->fontname;
     para->free_layout = NULL;
 
@@ -212,8 +211,8 @@ pointf textsize(graph_t *g, textpara_t * para, char *fontname, double fontsize)
 	estimate_textlayout(g, para, fp);
 
     if (fp)
-	fprintf(stderr, "%s: fontname \"%s\" resolved to: %s\n",
-		    GD_gvc(g)->common.cmdname, para->fontname, fontpath);
+	fprintf(stderr, "fontname: \"%s\" resolved to: %s\n",
+		    para->fontname, fontpath);
 
     size.x = para->width;
     size.y = para->height;
