@@ -1,4 +1,4 @@
-/* $Id: geomprocs.h,v 1.5 2006/12/07 22:49:35 erg Exp $ $Revision: 1.5 $ */
+/* $Id: geomprocs.h,v 1.9 2008/06/18 19:28:39 erg Exp $ $Revision: 1.9 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -24,6 +24,8 @@
 extern "C" {
 #endif
 
+#include <geom.h>
+
 extern point pointof(int, int);
 extern pointf pointfof(double, double);
 
@@ -70,7 +72,12 @@ extern point cwrotatep(point p, int cwrot);
 extern pointf cwrotatepf(pointf p, int cwrot);
 
 extern void rect2poly(pointf *p);
+extern pointf scale(double c, pointf v);
+extern pointf perp(pointf v);
+extern pointf subPt(pointf v, pointf w);
+extern pointf addPt(pointf v, pointf w);
 
+extern int seg_intersect (pointf a, pointf b, pointf c, pointf d, pointf* x);
 #ifdef __cplusplus
 }
 #endif
