@@ -1,4 +1,4 @@
-/* $Id: globals.h,v 1.30 2007/11/01 21:01:07 ellson Exp $ $Revision: 1.30 $ */
+/* $Id: globals.h,v 1.32 2008/02/07 17:09:46 ellson Exp $ $Revision: 1.32 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -92,7 +92,7 @@ extern "C" {
 	*G_selectedpencolor, *G_selectedfillcolor,
 	*G_visitedpencolor, *G_visitedfillcolor,
 	*G_deletedpencolor, *G_deletedfillcolor,
-	*G_peripheries;
+	*G_peripheries, *G_penwidth;
     EXTERN attrsym_t
 	*N_height, *N_width, *N_shape, *N_color, *N_fillcolor,
 	*N_activepencolor, *N_activefillcolor,
@@ -103,7 +103,8 @@ extern "C" {
 	*N_label, *N_nojustify, *N_style, *N_showboxes,
 	*N_sides, *N_peripheries, *N_orientation,
 	*N_skew, *N_distortion, *N_fixed, *N_imagescale, *N_layer,
-	*N_group, *N_comment, *N_vertices, *N_z;
+	*N_group, *N_comment, *N_vertices, *N_z,
+	*N_penwidth;
     EXTERN attrsym_t
 	*E_weight, *E_minlen, *E_color,
 	*E_activepencolor, *E_activefillcolor,
