@@ -1,4 +1,4 @@
-/* $Id: htmltable.c,v 1.57 2008/03/06 21:40:02 ellson Exp $ $Revision: 1.57 $ */
+/* $Id: htmltable.c,v 1.61 2008/06/25 20:37:41 erg Exp $ $Revision: 1.61 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -115,7 +115,6 @@ emit_htextparas(GVJ_t* job, int nparas, htextpara_t* paras, pointf p,
 {
     int i,j;
     double tmp, center_x, left_x, right_x, fsize_;
-    double offset;
     char *fname_ , *fcolor_;
     textpara_t tl;
     pointf p_ = {0.0, 0.0};
@@ -134,25 +133,22 @@ emit_htextparas(GVJ_t* job, int nparas, htextpara_t* paras, pointf p,
 
     gvrender_begin_context(job);
     for(i=0; i<nparas; i++) {
+	/* set p.x to leftmost point where the line of text begins */
 	switch (paras[i].just) {
 	case 'l':
-	    p_.x = left_x;
 	    p.x = left_x;
 	    break;
 	case 'r':
-	    p_.x = right_x;
-	    p.x = right_x;		
+	    p.x = right_x - paras[i].size;
 	    break;
 	default:
 	case 'n':
-	    p_.x = center_x;
-	    p.x = center_x;
+	    p.x = center_x - paras[i].size/2.0;
 	    break;
 	}
 	p_.y -= paras[i].lfsize;  /* move to current base line */
 
 	ti = paras[i].items;
-	offset = 0.0;
 	for(j=0; j<paras[i].nitems; j++) {
 	    if (ti->font && (ti->font->size > 0))
 		fsize_ = ti->font->size;
@@ -177,13 +173,18 @@ emit_htextparas(GVJ_t* job, int nparas, htextpara_t* paras, pointf p,
 	    tl.yoffset_centerline = ti->yoffset_centerline;
 	    tl.postscript_alias = ti->postscript_alias;
 	    tl.layout = ti->layout;
-	    tl.width = paras[i].size;
+	    tl.width = ti->size;
 	    tl.height = paras[i].lfsize;
-	    tl.just = paras[i].just;
 
+	    tl.just = 'l';
+	    p_.x = p.x;
+#if 0
+/* or */
+	    tl.just = 'c';
+	    p_.x = p.x + (ti->size/2.0);
+#endif
 	    gvrender_textpara(job, p_, &tl);
-	    offset += ti->size;
-	    p_.x = p.x + offset;
+	    p.x += ti->size;
             ti++;
 	}
     }
@@ -578,6 +579,7 @@ void free_html_data(htmldata_t * dp)
     free(dp->target);
     free(dp->title);
     free(dp->bgcolor);
+    free(dp->pencolor);
 }
 
 void free_html_text(htmltxt_t* t)
@@ -1763,7 +1765,8 @@ int make_html_label(graph_t *g, textlabel_t * lp, void *obj)
     }
 
     if (lbl->kind == HTML_TBL) {
-	lbl->u.tbl->data.pencolor = getPenColor(obj);
+	if (! lbl->u.tbl->data.pencolor && getPenColor(obj))
+	    lbl->u.tbl->data.pencolor = strdup(getPenColor(obj));
 	rv |= size_html_tbl(g, lbl->u.tbl, NULL, &env);
 	wd2 = (lbl->u.tbl->data.box.UR.x + 1) / 2;
 	ht2 = (lbl->u.tbl->data.box.UR.y + 1) / 2;
