@@ -1,4 +1,4 @@
-/* $Id: macros.h,v 1.15 2006/12/04 19:20:04 erg Exp $ $Revision: 1.15 $ */
+/* $Id: macros.h,v 1.16 2006/12/07 22:49:35 erg Exp $ $Revision: 1.16 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,6 +17,10 @@
 #ifndef GV_MACROS_H
 #define GV_MACROS_H
 
+#ifndef NOTUSED
+#define NOTUSED(var) (void) var
+#endif
+
 #define isPinned(n)     (ND_pinned(n) == P_PIN)
 #define hasPos(n)       (ND_pinned(n) > 0)
 #define isFixed(n)      (ND_pinned(n) > P_SET)
