@@ -1,4 +1,4 @@
-/* $Id: picgen.c,v 1.13 2006/07/10 23:25:37 ellson Exp $ $Revision: 1.13 $ */
+/* $Id: picgen.c,v 1.14 2006/12/07 22:49:36 erg Exp $ $Revision: 1.14 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -554,7 +554,7 @@ static void pic_polyline(point * A, int n)
     point_list_out(A, n, FALSE);
 }
 
-static void pic_usershape(usershape_t *us, boxf b, point *A, int n, bool filled)
+static void pic_usershape(usershape_t *us, boxf b, point *A, int n, boolean filled)
 {
 /* FIXME */
     /* it's not at all clear what xxx_user_shape is supposed to do; in most xxxgen.c files it emits a message */
