@@ -1,4 +1,4 @@
-/* $Id: pointset.c,v 1.5 2007/06/20 18:49:13 erg Exp $ $Revision: 1.5 $ */
+/* $Id: pointset.c,v 1.6 2008/01/03 23:24:28 ellson Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -15,7 +15,7 @@
 **********************************************************/
 
 
-#include <pointset.h>
+#include "pointset.h"
 
 typedef struct {
     Dtlink_t link;
