@@ -1,4 +1,4 @@
-/* $Id: pointset.h,v 1.2 2005/02/24 00:57:33 ellson Exp $ $Revision: 1.2 $ */
+/* $Id: pointset.h,v 1.3 2008/01/03 23:24:28 ellson Exp $ $Revision: 1.3 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -23,7 +23,7 @@ extern "C" {
 #ifndef _POINTSET_H
 #define _POINTSET_H 1
 
-#include <render.h>
+#include "render.h"
 
     typedef Dict_t PointSet;
     typedef Dict_t PointMap;
