@@ -1,4 +1,4 @@
-/* $Id: render.h,v 1.50 2008/02/29 22:00:16 ellson Exp $ $Revision: 1.50 $ */
+/* $Id: render.h,v 1.53 2008/04/21 15:08:18 erg Exp $ $Revision: 1.53 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -113,10 +113,15 @@ extern "C" {
     extern void global_def(char *,
 			   Agsym_t * (*fun) (Agraph_t *, char *, char *));
     extern int gvRenderJobs (GVC_t * gvc, graph_t * g);
+    extern void gv_free_splines(edge_t * e);
+    extern void gv_cleanup_edge(Agedge_t * e);
+    extern void gv_nodesize(Agnode_t * n, boolean flip);
+    extern void gv_cleanup_node(Agnode_t * n);
     extern int initMapData (GVJ_t*, char*, char*, char*, char*, void*);
     extern boolean isPolygon(node_t *);
     extern char *strdup_and_subst_obj(char *str, void *obj);
     extern char *xml_string(char *s);
+    extern char *xml_url_string(char *s);
     extern void makeSelfEdge(path *, edge_t **, int, int, int, int,
 			     splineInfo *);
     extern textlabel_t *make_label(graph_t *g, int html, char *str,
