@@ -1,4 +1,4 @@
-/* $Id: timing.c,v 1.1.1.1 2004/12/23 04:04:48 ellson Exp $ $Revision: 1.1.1.1 $ */
+/* $Id: timing.c,v 1.2 2006/07/27 02:20:56 erg Exp $ $Revision: 1.2 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -15,7 +15,7 @@
 **********************************************************/
 
 
-#ifndef MSWIN32
+#ifndef WIN32
 
 #include        <unistd.h>
 #include	<sys/types.h>
