@@ -1,4 +1,4 @@
-/* $Id: types.h,v 1.57 2007/09/04 21:40:01 erg Exp $ $Revision: 1.57 $ */
+/* $Id: types.h,v 1.59 2008/01/08 18:18:59 ellson Exp $ $Revision: 1.59 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -22,9 +22,15 @@
 #include <signal.h>
 
 typedef unsigned char boolean;
+#ifndef NOT
 #define NOT(v) (!(v))
+#endif
+#ifndef FALSE
 #define FALSE 0
+#endif
+#ifndef TRUE
 #define TRUE NOT(FALSE)
+#endif
 
 #include "geom.h"
 #include "gvcext.h"
@@ -185,7 +191,7 @@ extern "C" {
 	boolean usershape;
     } shape_desc;
 
-#include <usershape.h>		/* usershapes needed by gvc even w/o CODEGENS */
+#include "usershape.h"		/* usershapes needed by gvc even w/o CODEGENS */
 #ifdef WITH_CODEGENS
 
     struct codegen_s {
