@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.67 2008/02/22 14:21:42 glenlow Exp $ $Revision: 1.67 $ */
+/* $Id: utils.c,v 1.71 2008/04/21 15:08:18 erg Exp $ $Revision: 1.71 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -248,11 +248,13 @@ edge_t *debug_getedge(graph_t * g, char *s0, char *s1)
 static unsigned char userbuf[SMALLBUF];
 static agxbuf xb;
 
+#if 0
 static void cleanup(void)
 {
     agxbfree(&xb);
 }
 #endif
+#endif
 
 char *gvUsername(void)
 {
@@ -262,7 +264,9 @@ char *gvUsername(void)
     struct passwd *p;
     if (first) {
 	agxbinit(&xb, SMALLBUF, userbuf);
+#if 0
 	atexit(cleanup);
+#endif
 	first = 0;
     }
     p = (struct passwd *) getpwuid(getuid());
@@ -1367,7 +1371,7 @@ htmlEntity (char** s)
     return n;
 }
 
-/* substitute html entities like: &#123; and: &amp; for the UTF8 equivalents */
+/* substitute html entities like: &#123; and: &amp; with the UTF8 equivalents */
 char* htmlEntityUTF8 (char* s)
 {
     char*  ns;
@@ -1743,3 +1747,41 @@ int strncasecmp(const char *s1, const char *s2, unsigned int n)
 }
 
 #endif				/* HAVE_STRNCASECMP */
+
+void gv_free_splines(edge_t * e)
+{
+    int i;
+    if (ED_spl(e)) {
+        for (i = 0; i < ED_spl(e)->size; i++)
+            free(ED_spl(e)->list[i].list);
+        free(ED_spl(e)->list);
+        free(ED_spl(e));
+    }
+    ED_spl(e) = NULL;
+}
+
+void gv_cleanup_edge(edge_t * e)
+{
+    gv_free_splines(e);
+    free_label(ED_label(e));
+    memset(&(e->u), 0, sizeof(Agedgeinfo_t));
+}
+
+void gv_cleanup_node(node_t * n)
+{
+    if (ND_pos(n)) free(ND_pos(n));
+    if (ND_shape(n))
+        ND_shape(n)->fns->freefn(n);
+    free_label(ND_label(n));
+    memset(&(n->u), 0, sizeof(Agnodeinfo_t));
+}
+
+void gv_nodesize(node_t * n, boolean flip)
+{
+    int w;
+
+    w = ND_xsize(n) = POINTS(ND_width(n));
+    ND_lw_i(n) = ND_rw_i(n) = w / 2;
+    ND_ht_i(n) = ND_ysize(n) = POINTS(ND_height(n));
+}
+
