@@ -1,4 +1,4 @@
-/* $Id: vtxgen.c,v 1.12 2006/05/25 00:09:14 ellson Exp $ $Revision: 1.12 $ */
+/* $Id: vtxgen.c,v 1.13 2006/12/07 22:49:36 erg Exp $ $Revision: 1.13 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -598,7 +598,7 @@ static void vtx_polyline(point * A, int n)
     vtx_style();
 }
 
-static void vtx_usershape(usershape_t *us, boxf b, point *A, int n, bool filled)
+static void vtx_usershape(usershape_t *us, boxf b, point *A, int n, boolean filled)
 {
 /* FIXME */
     int i;
