@@ -1,4 +1,4 @@
-/* $Id: rank.c,v 1.10 2006/07/08 20:42:53 ellson Exp $ $Revision: 1.10 $ */
+/* $Id: rank.c,v 1.11 2007/09/28 14:38:43 north Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -195,8 +195,8 @@ node_induce(graph_t * par, graph_t * g)
     }
 }
 
-static void 
-scan_ranks(graph_t * g)
+void 
+dot_scan_ranks(graph_t * g)
 {
     node_t *n, *leader = NULL;
     GD_minrank(g) = MAXSHORT;
@@ -261,7 +261,7 @@ collapse_cluster(graph_t * g, graph_t * subg)
 	dot_rank(subg);
 	cluster_leader(subg);
     } else
-	scan_ranks(subg);
+	dot_scan_ranks(subg);
 }
 
 /* Execute union commands for "same rank" subgraphs and clusters. */
