@@ -1,4 +1,4 @@
-/* $Id: sameport.c,v 1.6 2005/03/09 04:55:23 erg Exp $ $Revision: 1.6 $ */
+/* $Id: sameport.c,v 1.7 2006/05/22 17:39:35 erg Exp $ $Revision: 1.7 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -165,7 +165,7 @@ static void sameport(node_t * u, elist * l, double arr_len)
 	(MC_SCALE * (ND_lw_i(u) + prt.p.x)) / (ND_lw_i(u) + ND_rw_i(u));
     prt.constrained = FALSE;
     prt.defined = TRUE;
-    prt.clip = 0;
+    prt.clip = FALSE;
     prt.theta = 0;
     prt.side = 0;
 
