@@ -1,9 +1,11 @@
 #ifndef _EXPARSE_H
 #define _EXPARSE_H
-/* A Bison parser, made by GNU Bison 2.1.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
-/* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+/* Skeleton interface for Bison's Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,10 +22,18 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.  */
 
-/* As a special exception, when this file is copied by Bison into a
-   Bison output file, you may use that output file without restriction.
-   This special exception was added by the Free Software Foundation
-   in version 1.24 of Bison.  */
+/* As a special exception, you may create a larger work that contains
+   part or all of the Bison parser skeleton and distribute that work
+   under terms of your choice, so long as that work isn't itself a
+   parser generator using the skeleton or a modified version thereof
+   as a parser skeleton.  Alternatively, if you modify or redistribute
+   the parser skeleton itself, you may (at your option) remove this
+   special exception, which will cause the skeleton and the resulting
+   Bison output files to be licensed under the GNU General Public
+   License without this special exception.
+
+   This special exception was added by the Free Software Foundation in
+   version 2.2 of Bison.  */
 
 /* Tokens.  */
 #ifndef EXTOKENTYPE
@@ -186,9 +196,10 @@
 
 
 
-#if ! defined (EXSTYPE) && ! defined (EXSTYPE_IS_DECLARED)
-#line 37 "../../lib/expr/exparse.y"
-typedef union EXSTYPE {
+#if ! defined EXSTYPE && ! defined EXSTYPE_IS_DECLARED
+typedef union EXSTYPE
+#line 45 "../../lib/expr/exparse.y"
+{
 	struct Exnode_s*expr;
 	double		floating;
 	struct Exref_s*	reference;
@@ -198,9 +209,10 @@ typedef union EXSTYPE {
 	char*		string;
 	void*		user;
 	struct Exbuf_s*	buffer;
-} EXSTYPE;
-/* Line 1447 of yacc.c.  */
-#line 202 "y.tab.h"
+}
+/* Line 1489 of yacc.c.  */
+#line 213 "y.tab.h"
+	EXSTYPE;
 # define exstype EXSTYPE /* obsolescent; will be withdrawn */
 # define EXSTYPE_IS_DECLARED 1
 # define EXSTYPE_IS_TRIVIAL 1
@@ -208,6 +220,4 @@ typedef union EXSTYPE {
 
 extern EXSTYPE exlval;
 
-
-
 #endif /* _EXPARSE_H */
