@@ -1,4 +1,4 @@
-/* $Id: clusteredges.h,v 1.1.1.1 2004/12/23 04:05:09 ellson Exp $ $Revision: 1.1.1.1 $ */
+/* $Id: clusteredges.h,v 1.2 2008/04/08 21:34:51 erg Exp $ $Revision: 1.2 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -22,8 +22,9 @@ extern "C" {
 #define CLUSTEREDGES_H
 
 #include <render.h>
+#include <adjust.h>
 
-    extern int compoundEdges(graph_t * g, double SEP, int splines);
+    extern int compoundEdges(graph_t * g, expand_t* pm, int splines);
 
 #endif
 
