@@ -1,4 +1,4 @@
-/* $Id: fdpinit.c,v 1.11 2007/06/28 18:04:10 erg Exp $ $Revision: 1.11 $ */
+/* $Id: fdpinit.c,v 1.14 2008/04/21 19:12:09 erg Exp $ $Revision: 1.14 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -65,11 +65,6 @@ static void initialPositions(graph_t * g)
     }
 }
 
-static void fdp_initNode(node_t * n)
-{
-    neato_init_node(n);
-}
-
 /* init_edge:
  */
 static void init_edge(edge_t * e, attrsym_t * E_len)
@@ -94,7 +89,7 @@ void fdp_init_node_edge(graph_t * g)
     GD_neato_nlist(g) = N_NEW(nn + 1, node_t *);
 
     for (i = 0, n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	fdp_initNode (n);
+	neato_init_node (n);
 	ND_alg(n) = alg + i;
 	GD_neato_nlist(g)[i] = n;
 	ND_id(n) = i++;
@@ -110,34 +105,6 @@ void fdp_init_node_edge(graph_t * g)
 
 }
 
-static void fdp_cleanup_node(node_t * n)
-{
-    free(ND_pos(n));
-    if (ND_shape(n))
-	ND_shape(n)->fns->freefn(n);
-    free_label(ND_label(n));
-    memset(&(n->u), 0, sizeof(Agnodeinfo_t));
-}
-
-static void fdp_free_splines(edge_t * e)
-{
-    int i;
-    if (ED_spl(e)) {
-	for (i = 0; i < ED_spl(e)->size; i++)
-	    free(ED_spl(e)->list[i].list);
-	free(ED_spl(e)->list);
-	free(ED_spl(e));
-    }
-    ED_spl(e) = NULL;
-}
-
-static void fdp_cleanup_edge(edge_t * e)
-{
-    fdp_free_splines(e);
-    free_label(ED_label(e));
-    memset(&(e->u), 0, sizeof(Agedgeinfo_t));
-}
-
 static void cleanup_subgs(graph_t * g)
 {
     graph_t *mg;
@@ -175,9 +142,9 @@ void fdp_cleanup(graph_t * g)
     free(ND_alg(n));
     for (; n; n = agnxtnode(g, n)) {
 	for (e = agfstedge(g, n); e; e = agnxtedge(g, e, n)) {
-	    fdp_cleanup_edge(e);
+	    gv_cleanup_edge(e);
 	}
-	fdp_cleanup_node(n);
+	gv_cleanup_node(n);
     }
     fdp_cleanup_graph(g);
 }
