@@ -1,4 +1,4 @@
-/* $Id: layout.c,v 1.21 2008/03/03 23:01:51 ellson Exp $ $Revision: 1.21 $ */
+/* $Id: layout.c,v 1.22 2008/04/30 17:46:04 erg Exp $ $Revision: 1.22 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -1090,12 +1090,12 @@ fdpSplines (graph_t * g)
 	    if (trySplines)
 		Nop = 2;
 	}
-	if (trySplines || (et == ET_SPLINE)) {
+	if (trySplines || (et != ET_COMPOUND)) {
 	    if (HAS_CLUST_EDGE(g)) {
 		agerr(AGWARN,
 		      "splines and cluster edges not supported - using line segments\n");
 	    } else {
-		spline_edges1(g, ET_SPLINE);
+		spline_edges1(g, et);
 	    }
 	}
     }
