@@ -1,4 +1,4 @@
-/* $Id: graph.h,v 1.8 2008/02/08 10:50:53 glenlow Exp $ $Revision: 1.8 $ */
+/* $Id: graph.h,v 1.11 2008/06/09 16:57:01 erg Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -136,6 +136,7 @@ extern "C" {
 #endif
     extern char *agstrcanon(char *, char *);
     extern char *agcanonical(char *);
+    extern char *agcanon(char *);
     extern int aghtmlstr(char *s);
     extern char *agget(void *, char *);
     extern char *agxget(void *, int);
@@ -157,6 +158,8 @@ extern "C" {
     extern int agwrite(Agraph_t *, FILE *);
     extern int agerrors(void);
     extern Agraph_t *agprotograph(void);
+    extern Agnode_t *agprotonode(Agraph_t *);
+    extern Agedge_t *agprotoedge(Agraph_t *);
     extern Agraph_t *agusergraph(Agnode_t *);
     extern int agnnodes(Agraph_t *);
     extern int agnedges(Agraph_t *);
@@ -166,7 +169,6 @@ extern "C" {
     extern int agcontains(Agraph_t *, void *);
 
     extern Agnode_t *agnode(Agraph_t *, char *);
-    extern Agsym_t *agnodeattr(Agraph_t *, char *, char *);
     extern Agnode_t *agfindnode(Agraph_t *, char *);
     extern Agnode_t *agfstnode(Agraph_t *);
     extern Agnode_t *agnxtnode(Agraph_t *, Agnode_t *);
@@ -174,7 +176,6 @@ extern "C" {
     extern Agnode_t *agprvnode(Agraph_t *, Agnode_t *);
 
     extern Agedge_t *agedge(Agraph_t *, Agnode_t *, Agnode_t *);
-    extern Agsym_t *agedgeattr(Agraph_t *, char *, char *);
     extern Agedge_t *agfindedge(Agraph_t *, Agnode_t *, Agnode_t *);
     extern Agedge_t *agfstedge(Agraph_t *, Agnode_t *);
     extern Agedge_t *agnxtedge(Agraph_t *, Agedge_t *, Agnode_t *);
@@ -183,11 +184,16 @@ extern "C" {
     extern Agedge_t *agfstout(Agraph_t *, Agnode_t *);
     extern Agedge_t *agnxtout(Agraph_t *, Agedge_t *);
 
+    extern Agsym_t *agattr(void *, char *, char *);
     extern Agsym_t *agraphattr(Agraph_t *, char *, char *);
     extern Agsym_t *agnodeattr(Agraph_t *, char *, char *);
     extern Agsym_t *agedgeattr(Agraph_t *, char *, char *);
     extern Agsym_t *agfindattr(void *, char *);
-    extern int      agcopyattr(void *, void *);
+    extern Agsym_t *agfstattr(void *);
+    extern Agsym_t *agnxtattr(void *, Agsym_t *);
+    extern Agsym_t *aglstattr(void *);
+    extern Agsym_t *agprvattr(void *, Agsym_t *);
+    extern int      agcopyattr(void *, void *);	
 
     typedef enum { AGWARN, AGERR, AGMAX, AGPREV } agerrlevel_t;
     extern agerrlevel_t agerrno;
@@ -198,6 +204,7 @@ extern "C" {
     extern void agwarningf(char *fmt, ...);
 
     extern char *agstrdup(char *);
+    extern char *agstrdup_html(char *s);
     extern void agstrfree(char *);
 
     typedef enum { AGNODE = 1, AGEDGE, AGGRAPH } agobjkind_t;
