@@ -1,4 +1,4 @@
-/* $Id: gvc.c,v 1.32 2008/02/02 09:11:28 glenlow Exp $ $Revision: 1.32 $ */
+/* $Id: gvc.c,v 1.34 2008/05/23 14:34:36 glenlow Exp $ $Revision: 1.34 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -189,7 +189,7 @@ int gvRenderData(GVC_t *gvc, graph_t *g, char *format, char **result, unsigned i
     gvdevice_finalize(job);
 
     *result = job->output_data;
-	*length = job->output_data_position;
+    *length = job->output_data_position;
     gvjobs_delete(gvc);
 
     return 0;
@@ -199,3 +199,8 @@ char **gvcInfo(GVC_t* gvc) { return gvc->common.info; }
 char *gvcUsername(GVC_t* gvc) { return gvc->common.user; }
 char *gvcVersion(GVC_t* gvc) { return gvc->common.info[1]; }
 char *gvcBuildDate(GVC_t* gvc) { return gvc->common.info[2]; }
+
+gvplugin_available_t *gvFirstPlugin(GVC_t *gvc, api_t api) { return gvc->apis[api]; }
+gvplugin_available_t *gvNextPlugin(gvplugin_available_t *plugin) { return plugin->next; }
+char *gvPluginType(gvplugin_available_t *plugin) { return plugin->typestr; }
+
