@@ -1,4 +1,4 @@
-/* $Id: gvconfig.c,v 1.82 2008/02/28 06:10:45 glenlow Exp $ $Revision: 1.82 $ */
+/* $Id: gvconfig.c,v 1.87 2008/06/06 14:29:54 ellson Exp $ $Revision: 1.87 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -248,14 +248,9 @@ static void gvconfig_write_library_config(GVC_t *gvc, char *path, gvplugin_libra
     for (apis = library->apis; (types = apis->types); apis++) {
         fprintf(f, "\t%s {\n", gvplugin_api_name(apis->api));
 	for (i = 0; types[i].type; i++) {
-#if 0
-/* this was a good idea, but fails because we need a config to load
- * by plugin name, and were still generating the config.
- */
 	    /* verify that dependencies are available */
             if (! (gvplugin_load(gvc, apis->api, types[i].type)))
 		fprintf(f, "#FAILS");
-#endif
 	    fprintf(f, "\t\t%s %d\n", types[i].type, types[i].quality);
 	}
 	fputs ("\t}\n", f);
@@ -273,17 +268,18 @@ char * gvconfig_libdir(void)
     FILE *f;
 
     if (!libdir) {
-#ifdef WIN32
         libdir=getenv("GVBINDIR");
 	if (!libdir) {
+#ifdef WIN32
 	    int r;
 	    char* s;
-	    HMODULE hm = GetModuleHandle (NULL);
-	    if (!hm) {
+		
+		MEMORY_BASIC_INFORMATION mbi;
+		if (VirtualQuery (&gvconfig_libdir, &mbi, sizeof(mbi)) == 0) {
 		agerr(AGERR,"failed to get handle for executable.\n");
 		return 0;
 	    }
-	    r = GetModuleFileName (hm, line, BSZ);
+	    r = GetModuleFileName ((HMODULE)mbi.AllocationBase, line, BSZ);
 	    if (!r || (r == BSZ)) {
 		agerr(AGERR,"failed to get path for executable.\n");
 		return 0;
@@ -295,35 +291,35 @@ char * gvconfig_libdir(void)
 	    }
 	    *s = '\0';
 	    libdir = line;
-	}
 #else
-        /* this only works on linux, other systems will get GVLIBDIR only */
-	libdir = GVLIBDIR;
-        f = fopen ("/proc/self/maps", "r");
-        if (f) {
-            while (!feof (f)) {
-	        if (!fgets (line, sizeof (line), f))
-	            continue;
-	        if (!strstr (line, " r-xp "))
-	            continue;
-		path = strchr (line, '/');
-		if (!path)
-		    continue;
-		tmp = strstr (path, "/libgvc.");
-		if (tmp) {
-		    *tmp = 0;
-		    /* Check for real /lib dir. Don't accept pre-install /.libs */
-		    if (strcmp(strrchr(path,'/'), "/.libs") == 0)
+	    /* this only works on linux, other systems will get GVLIBDIR only */
+	    libdir = GVLIBDIR;
+	    f = fopen ("/proc/self/maps", "r");
+	    if (f) {
+		while (!feof (f)) {
+		    if (!fgets (line, sizeof (line), f))
 			continue;
-		    strcpy(line, path);  /* use line buffer for result */
-		    strcat(line, "/graphviz");  /* plugins are in "graphviz" subdirectory */
-		    libdir = line;
-		    break;
-	        }
-            }
-            fclose (f);
-        }
+		    if (!strstr (line, " r-xp "))
+			continue;
+		    path = strchr (line, '/');
+		    if (!path)
+		        continue;
+		    tmp = strstr (path, "/libgvc.");
+		    if (tmp) {
+			*tmp = 0;
+			/* Check for real /lib dir. Don't accept pre-install /.libs */
+			if (strcmp(strrchr(path,'/'), "/.libs") == 0)
+			    continue;
+			strcpy(line, path);  /* use line buffer for result */
+			strcat(line, "/graphviz");  /* plugins are in "graphviz" subdirectory */
+			libdir = line;
+			break;
+		    }
+		}
+		fclose (f);
+	    }
 #endif
+	}
     }
     return libdir;
 }
@@ -356,7 +352,7 @@ static void config_rescan(GVC_t *gvc, char *config_path)
     char *plugin_glob = "gvplugin_*";
     char *plugin_re_beg = "[^0-9]";
     char *plugin_re_end = "\\.dll$"; 
-#elif defined(__hpux__) || defined(__hpux)
+#elif ((defined(__hpux__) || defined(__hpux)) && !(defined(__ia64)))
     char *plugin_re_beg = "\\.sl\\.";
     char *plugin_re_end = "$"; 
 #else
@@ -408,6 +404,15 @@ static void config_rescan(GVC_t *gvc, char *config_path)
 		library = gvplugin_library_load(gvc, globbuf.gl_pathv[i]);
 		if (library) {
 		    gvconfig_plugin_install_from_library(gvc, globbuf.gl_pathv[i], library);
+		}
+	    }
+	}
+	/* rescan with all libs loaded to check cross dependencies */
+	for (i = 0; i < globbuf.gl_pathc; i++) {
+	    re_status = regexec(&re, globbuf.gl_pathv[i], (size_t) 0, NULL, 0);
+	    if (re_status == 0) {
+		library = gvplugin_library_load(gvc, globbuf.gl_pathv[i]);
+		if (library) {
 		    path = strrchr(globbuf.gl_pathv[i],DIRSEP[0]);
 		    if (path)
 			path++;
@@ -492,8 +497,8 @@ void gvconfig(GVC_t * gvc, boolean rescan)
         libdir = gvconfig_libdir();
         rc = stat(libdir, &libdir_st);
         if (rc == -1) {
-    	/* if we fail to stat it then it probably doesn't exist so just fail silently */
-    	return;
+    	    /* if we fail to stat it then it probably doesn't exist so just fail silently */
+	    return;
         }
     
         if (! gvc->config_path) {
@@ -504,42 +509,43 @@ void gvconfig(GVC_t * gvc, boolean rescan)
         }
     	
         if (rescan) {
-    	config_rescan(gvc, gvc->config_path);
-    	gvc->config_found = TRUE;
-    	return;
+    	    config_rescan(gvc, gvc->config_path);
+    	    gvc->config_found = TRUE;
+    	    return;
         }
     
         /* load in the cached plugin library data */
     
         rc = stat(gvc->config_path, &config_st);
         if (rc == -1) {
-    	/* silently return without setting gvc->config_found = TRUE */
-    	return;
+    	    /* silently return without setting gvc->config_found = TRUE */
+    	    return;
         }
         else if (config_st.st_size > MAX_SZ_CONFIG) {
-    	agerr(AGERR,"%s is bigger than I can handle.\n", gvc->config_path);
+    	    agerr(AGERR,"%s is bigger than I can handle.\n", gvc->config_path);
         }
         else {
-    	f = fopen(gvc->config_path,"r");
-    	if (!f) {
-    	    agerr (AGERR,"failed to open %s for read.\n", gvc->config_path);
-    	}
-    	else {
-    	    config_text = gmalloc(config_st.st_size + 1);
-    	    sz = fread(config_text, 1, config_st.st_size, f);
-    	    if (sz == 0) {
-    		agerr(AGERR,"%s is zero sized, or other read error.\n", gvc->config_path);
-    		free(config_text);
+    	    f = fopen(gvc->config_path,"r");
+    	    if (!f) {
+    	        agerr (AGERR,"failed to open %s for read.\n", gvc->config_path);
     	    }
     	    else {
-    	        gvc->config_found = TRUE;
-    	        config_text[sz] = '\0';  /* make input into a null terminated string */
-    	        rc = gvconfig_plugin_install_from_config(gvc, config_text);
-    		/* NB. config_text not freed because we retain char* into it */
+    	        config_text = gmalloc(config_st.st_size + 1);
+    	        sz = fread(config_text, 1, config_st.st_size, f);
+    	        if (sz == 0) {
+    		    agerr(AGERR,"%s is zero sized, or other read error.\n", gvc->config_path);
+    		    free(config_text);
+    	        }
+    	        else {
+    	            gvc->config_found = TRUE;
+    	            config_text[sz] = '\0';  /* make input into a null terminated string */
+    	            rc = gvconfig_plugin_install_from_config(gvc, config_text);
+    		    /* NB. config_text not freed because we retain char* into it */
+    	        }
     	    }
-    	}
-    	if (f)
-    	    fclose(f);
+    	    if (f) {
+    	        fclose(f);
+	    }
         }
     }
 #endif
