@@ -1,4 +1,4 @@
-/* $Id: gvcontext.c,v 1.19 2006/11/28 20:08:44 erg Exp $ $Revision: 1.19 $ */
+/* $Id: gvcontext.c,v 1.20 2007/11/02 20:30:28 ellson Exp $ $Revision: 1.20 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -57,12 +57,9 @@ GVC_t *gvNEWcontext(char **info, char *user)
 int gvFreeContext(GVC_t * gvc)
 {
     GVG_t *gvg, *gvg_next;
-    GVJ_t *firstjob;
 
-    if ((firstjob = gvc->active_jobs)) {
-	gvrender_end_job(firstjob);
-	gvdevice_finalize(firstjob);
-    }
+    if (gvc->active_jobs)
+	gvrender_end_job(gvc->active_jobs);
     emit_once_reset();
     gvg_next = gvc->gvgs;
     while ((gvg = gvg_next)) {
