@@ -1,4 +1,4 @@
-/* $Id: gvcproc.h,v 1.35 2007/12/21 01:48:33 ellson Exp $ $Revision: 1.35 $ */
+/* $Id: gvcproc.h,v 1.36 2008/03/15 23:19:30 ellson Exp $ $Revision: 1.36 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -63,12 +63,11 @@ extern "C" {
     extern void gvloadimage(GVJ_t *job, usershape_t *us, boxf b, boolean filled, char *target);
     
 /* usershapes */
-    extern point gvusershape_size_dpi(usershape_t*, pointf);
+    extern point gvusershape_size_dpi(usershape_t *us, pointf dpi);
     extern point gvusershape_size(graph_t *g, char *name);
     extern usershape_t *gvusershape_find(char *name);
 
 /* device */
-
     extern size_t gvdevice_write (GVJ_t * job, const unsigned char *s, unsigned int len);
     extern void gvdevice_fputs(GVJ_t * job, char *s);
     extern void gvdevice_printf(GVJ_t * job, const char *format, ...);
