@@ -1,4 +1,4 @@
-/* $Id: gvjobs.c,v 1.25 2006/08/25 22:32:50 erg Exp $ $Revision: 1.25 $ */
+/* $Id: gvjobs.c,v 1.29 2007/08/29 19:39:49 ellson Exp $ $Revision: 1.29 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -66,7 +66,7 @@ void gvjobs_output_filename(GVC_t * gvc, char *name)
 }
 
 /* -T switches */
-bool gvjobs_output_langname(GVC_t * gvc, char *name)
+boolean gvjobs_output_langname(GVC_t * gvc, char *name)
 {
     if (!gvc->jobs) {
 	output_langname_job = gvc->job = gvc->jobs = zmalloc(sizeof(GVJ_t));
@@ -84,7 +84,7 @@ bool gvjobs_output_langname(GVC_t * gvc, char *name)
     output_langname_job->gvc = gvc;
 
     /* load it now to check that it exists */
-    if (gvplugin_load(gvc, API_render, name))
+    if (gvplugin_load(gvc, API_device, name))
 	return TRUE;
     return FALSE;
 }
