@@ -1,4 +1,4 @@
-/* $Id: gvlayout.c,v 1.24 2006/08/24 21:07:45 erg Exp $ $Revision: 1.24 $ */
+/* $Id: gvlayout.c,v 1.25 2006/12/07 22:49:36 erg Exp $ $Revision: 1.25 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -25,11 +25,11 @@
 
 #include "const.h"
 #include "gvplugin_layout.h"
-#include "graph.h"
 #include "gvcint.h"
+#include "graph.h"
 #include "gvcproc.h"
 
-extern void graph_init(graph_t *g, bool use_rankdir);
+extern void graph_init(graph_t *g, boolean use_rankdir);
 extern void graph_cleanup(graph_t *g);
 
 int gvlayout_select(GVC_t * gvc, char *layout)
