@@ -1,4 +1,4 @@
-/* $Id: gvplugin_device.h,v 1.6 2005/10/18 18:47:22 ellson Exp $ $Revision: 1.6 $ */
+/* $Id: gvplugin_device.h,v 1.13 2007/10/03 16:59:11 ellson Exp $ $Revision: 1.13 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,6 +17,7 @@
 #ifndef GVDEVICE_PLUGIN_H
 #define GVDEVICE_PLUGIN_H
 
+#include "types.h"
 #include "gvplugin.h"
 #include "gvcjob.h"
 
@@ -25,6 +26,8 @@ extern "C" {
 #endif
 
     struct gvdevice_engine_s {
+	void (*initialize) (GVJ_t * firstjob);
+	void (*format) (GVJ_t * firstjob);
 	void (*finalize) (GVJ_t * firstjob);
     };
 
