@@ -1,4 +1,4 @@
-/* $Id: gvplugin_render.h,v 1.28 2007/10/03 19:00:06 ellson Exp $ $Revision: 1.28 $ */
+/* $Id: gvplugin_render.h,v 1.29 2007/12/19 22:03:36 ellson Exp $ $Revision: 1.29 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -23,6 +23,9 @@
 
 extern void gvdevice_fputs(GVJ_t * job, char *s);
 extern void gvdevice_printf(GVJ_t * job, const char *format, ...);
+extern void gvdevice_printnum(GVJ_t * job, double num);
+extern void gvdevice_printpointf(GVJ_t * job, pointf p);
+extern void gvdevice_printpointflist(GVJ_t * job, pointf *p, int n);
 
 #ifdef __cplusplus
 extern "C" {
