@@ -1,4 +1,4 @@
-/* $Id: gvplugin_textlayout.h,v 1.5 2005/10/18 18:56:10 ellson Exp $ $Revision: 1.5 $ */
+/* $Id: gvplugin_textlayout.h,v 1.14 2007/08/30 19:20:21 ellson Exp $ $Revision: 1.14 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -14,21 +14,23 @@
 *              AT&T Research, Florham Park NJ             *
 **********************************************************/
 
-#ifndef GVTEXTLAYOUT_PLUGIN_H
-#define GVTEXTLAYOUT_PLUGIN_H
+#ifndef GVPLUGIN_TEXTLAYOUT_H
+#define GVPLUGIN_TEXTLAYOUT_H
 
+#include "types.h"
 #include "gvplugin.h"
-#include "gvcint.h"
+#include "gvcjob.h"
+#include "gvcommon.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
     struct gvtextlayout_engine_s {
-	void (*width) (textline_t *textline, char *fontname, double fontsize, char* fontpath);
+	boolean (*textlayout) (textpara_t *para, char** fontpath);
     };
 
 #ifdef __cplusplus
 }
 #endif
-#endif				/* GVTEXTLAYOUT_PLUGIN_H */
+#endif				/* GVPLUGIN_TEXTLAYOUT_H */
