@@ -1,4 +1,4 @@
-/* $Id: gvrender.c,v 1.142 2007/12/04 21:22:17 erg Exp $ $Revision: 1.142 $ */
+/* $Id: gvrender.c,v 1.144 2008/06/06 18:15:54 ellson Exp $ $Revision: 1.144 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -669,7 +669,10 @@ void gvrender_set_pencolor(GVJ_t * job, char *name)
 {
     gvrender_engine_t *gvre = job->render.engine;
     gvcolor_t *color = &(job->obj->pencolor);
+    char *cp = NULL;
 
+    if ((cp = strstr(name, ":"))) /* if its a color list, then use only first */
+	*cp = '\0';
     if (gvre) {
 	gvrender_resolve_color(job->render.features, name, color);
 	if (gvre->resolve_color)
@@ -683,13 +686,18 @@ void gvrender_set_pencolor(GVJ_t * job, char *name)
 	    cg->set_pencolor(name);
     }
 #endif
+    if (cp)  /* restore color list */
+	*cp = ':';
 }
 
 void gvrender_set_fillcolor(GVJ_t * job, char *name)
 {
     gvrender_engine_t *gvre = job->render.engine;
     gvcolor_t *color = &(job->obj->fillcolor);
+    char *cp = NULL;
 
+    if ((cp = strstr(name, ":"))) /* if its a color list, then use only first */
+	*cp = '\0';
     if (gvre) {
 	gvrender_resolve_color(job->render.features, name, color);
 	if (gvre->resolve_color)
@@ -703,6 +711,8 @@ void gvrender_set_fillcolor(GVJ_t * job, char *name)
 	    cg->set_fillcolor(name);
     }
 #endif
+    if (cp)
+	*cp = ':';
 }
 
 void gvrender_set_style(GVJ_t * job, char **s)
