@@ -1,4 +1,4 @@
-/* $Id: gvtextlayout.c,v 1.20 2006/07/17 18:03:47 ellson Exp $ $Revision: 1.20 $ */
+/* $Id: gvtextlayout.c,v 1.23 2007/08/30 19:20:21 ellson Exp $ $Revision: 1.23 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -41,13 +41,11 @@ int gvtextlayout_select(GVC_t * gvc)
     return NO_SUPPORT;
 }
 
-bool gvtextlayout(GVC_t *gvc, textpara_t *para, char **fontpath)
+boolean gvtextlayout(GVC_t *gvc, textpara_t *para, char **fontpath)
 {
     gvtextlayout_engine_t *gvte = gvc->textlayout.engine;
 
-    if (gvte && gvte->textlayout) {
-	gvte->textlayout(&(gvc->common), para, fontpath);
-	return TRUE;
-    }
+    if (gvte && gvte->textlayout)
+	return gvte->textlayout(para, fontpath);
     return FALSE;
 }
