@@ -1,4 +1,4 @@
-/* $Id: no_builtins.c,v 1.4 2006/06/11 19:59:03 ellson Exp $ $Revision: 1.4 $ */
+/* $Id: no_builtins.c,v 1.5 2007/06/08 22:09:14 erg Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -20,4 +20,8 @@
 
 #include "gvcext.h"
 
+#if defined(GVDLL) && !defined(ENABLE_LTDL)
+lt_symlist_t lt_preloaded_symbols[] = { { 0, 0 } };
+#else
 const lt_symlist_t lt_preloaded_symbols[] = { { 0, 0 } };
+#endif
