@@ -1,4 +1,4 @@
-/* $Id: ingraphs.c,v 1.1.1.1 2004/12/23 04:05:22 ellson Exp $ $Revision: 1.1.1.1 $ */
+/* $Id: ingraphs.c,v 1.4 2007/06/25 18:34:23 erg Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -52,8 +52,10 @@ static void nextFile(ingraph_state * sp)
 		break;
 	    } else if ((rv = sp->fns->openf(fname)) != 0)
 		break;
-	    else
+	    else {
 		fprintf(stderr, "Can't open %s\n", sp->Files[sp->ctr - 1]);
+		sp->errors++;
+	    }
 	}
     }
     if (rv)
@@ -100,6 +102,7 @@ ingraph_state *newIng(ingraph_state * sp, char **files, ingdisc * disc)
 	sp->heap = 0;
     sp->Files = files;
     sp->ctr = 0;
+    sp->errors = 0;
     sp->fp = NULL;
     sp->fns = (ingdisc *) malloc(sizeof(ingdisc));
     if (!sp->fns) {
@@ -182,3 +185,78 @@ char *fileName(ingraph_state * sp)
     } else
 	return "<stdin>";
 }
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifndef HAVE_GETOPT_DECL
+/*
+public domain AT&T getopt source
+*/
+#include <string.h>
+
+/*LINTLIBRARY*/
+
+#if 0
+#define EOF	(-1)
+#define ERR(s, c)	if(opterr){\
+	char errbuf[2];\
+	errbuf[0] = c; errbuf[1] = '\n';\
+	(void) write(2, argv[0], (unsigned)strlen(argv[0]));\
+	(void) write(2, s, (unsigned)strlen(s));\
+	(void) write(2, errbuf, 2);}
+#endif
+#define ERR(s, c)	if(opterr) fprintf (stderr, "%s%s'%c'\n", argv[0], s, c)
+
+int	opterr = 1;
+int	optind = 1;
+int	optopt;
+char	*optarg;
+
+int
+getopt(int argc, char** argv, char* opts)
+{
+	static int sp = 1;
+	register int c;
+	register char *cp;
+
+	if(sp == 1) {
+		if(optind >= argc ||
+		   argv[optind][0] != '-' || argv[optind][1] == '\0')
+			return(EOF);
+		else if(strcmp(argv[optind], "--") == 0) {
+			optind++;
+			return(EOF);
+		}
+	}
+
+	optopt = c = argv[optind][sp];
+	if(c == ':' || (cp=strchr(opts, c)) == 0) {
+		ERR(": illegal option -- ", c);
+		if(argv[optind][++sp] == '\0') {
+			optind++;
+			sp = 1;
+		}
+		return('?');
+	}
+	if(*++cp == ':') {
+		if(argv[optind][sp+1] != '\0')
+			optarg = &argv[optind++][sp+1];
+		else if(++optind >= argc) {
+			ERR(": option requires an argument -- ", c);
+			sp = 1;
+			return('?');
+		} else
+			optarg = argv[optind++];
+		sp = 1;
+	} else {
+		if(argv[optind][++sp] == '\0') {
+			sp = 1;
+			optind++;
+		}
+		optarg = 0;
+	}
+	return(c);
+}
+#endif
