@@ -1,4 +1,4 @@
-/* $Id: adjust.h,v 1.7 2006/05/11 21:47:36 erg Exp $ $Revision: 1.7 $ */
+/* $Id: adjust.h,v 1.10 2008/05/28 17:44:56 erg Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -23,12 +23,16 @@
 extern "C" {
 #endif
 
+#include <geom.h>
+
+#define DFLT_MARGIN     4   /* 4 points */
+
 typedef enum {
-    AM_NONE, AM_VOR, AM_COMPRESS,
+    AM_NONE, AM_VOR,
     AM_SCALE, AM_NSCALE, AM_SCALEXY, AM_PUSH, AM_PUSHPULL,
     AM_ORTHO, AM_ORTHO_YX, AM_ORTHOXY, AM_ORTHOYX,
-    AM_PORTHO, AM_PORTHO_YX, AM_PORTHOXY, AM_PORTHOYX,
-    AM_VPSC, AM_IPSEP
+    AM_PORTHO, AM_PORTHO_YX, AM_PORTHOXY, AM_PORTHOYX, AM_COMPRESS,
+    AM_VPSC, AM_IPSEP, AM_FDP
 } adjust_mode;
 
 typedef struct {
@@ -37,7 +41,13 @@ typedef struct {
     char *print;
 } adjust_data;
 
-    extern double expFactor(graph_t * G);
+typedef struct {
+    float x, y;
+    boolean doAdd;  /* if true, x and y are in points */
+} expand_t;
+
+    extern expand_t sepFactor(graph_t * G);
+    extern expand_t esepFactor(graph_t * G);
     extern int adjustNodes(graph_t * G);
     extern void normalize(graph_t * g);
     extern int removeOverlap(graph_t * G);
