@@ -1,4 +1,4 @@
-/* $Id: bfs.c,v 1.2 2006/07/08 20:42:53 ellson Exp $ $Revision: 1.2 $ */
+/* $Id: bfs.c,v 1.3 2006/12/07 22:49:36 erg Exp $ $Revision: 1.3 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -154,20 +154,20 @@ void initQueue(Queue * qp, int startVertex)
     qp->end = 1;
 }
 
-bool deQueue(Queue * qp, int *vertex)
+boolean deQueue(Queue * qp, int *vertex)
 {
     if (qp->start >= qp->end)
-	return false;		/* underflow */
+	return FALSE;		/* underflow */
     *vertex = qp->data[qp->start++];
-    return true;
+    return TRUE;
 }
 
-bool enQueue(Queue * qp, int vertex)
+boolean enQueue(Queue * qp, int vertex)
 {
     if (qp->end >= qp->queueSize)
-	return false;		/* overflow */
+	return FALSE;		/* overflow */
     qp->data[qp->end++] = vertex;
-    return true;
+    return TRUE;
 }
 
 #endif
