@@ -1,4 +1,4 @@
-/* $Id: constrained_majorization.c,v 1.5 2006/12/07 22:49:36 erg Exp $ $Revision: 1.5 $ */
+/* $Id: constrained_majorization.c,v 1.6 2008/04/25 14:38:29 erg Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -39,6 +39,7 @@ stress_majorization_with_hierarchy(
     int n,              /* Number of nodes */
     int nedges_graph,   /* Number of edges */
     double** d_coords,  /* Coordinates of nodes (output layout)  */
+    node_t** nodes,     /* Original nodes */
     int dim,            /* Dimemsionality of layout */
     int smart_ini,      /* smart initialization */
     int model,          /* difference model */
@@ -100,7 +101,7 @@ stress_majorization_with_hierarchy(
 		}
 	}
 	if (!directionalityExist) {
-		return stress_majorization_kD_mkernel(graph, n, nedges_graph, d_coords, dim, smart_ini, model, maxi);
+		return stress_majorization_kD_mkernel(graph, n, nedges_graph, d_coords, nodes, dim, smart_ini, model, maxi);
 	}
 
 	/******************************************************************
@@ -112,7 +113,7 @@ stress_majorization_with_hierarchy(
 		double* y;
 		if (dim>2) {
 			/* the dim==2 case is handled below			 */
-			stress_majorization_kD_mkernel(graph, n, nedges_graph, d_coords+1, dim-1, smart_ini, model, 15);
+			stress_majorization_kD_mkernel(graph, n, nedges_graph, d_coords+1, nodes, dim-1, smart_ini, model, 15);
 			/* now copy the y-axis into the (dim-1)-axis */
 			for (i=0; i<n; i++) {
 				d_coords[dim-1][i] = d_coords[1][i];
@@ -124,7 +125,7 @@ stress_majorization_with_hierarchy(
 		compute_hierarchy(graph, n, abs_tol, relative_tol, y, &ordering, &levels, &num_levels);
 		if (num_levels<=1) {
 			/* no hierarchy found, use faster algorithm */
-			return stress_majorization_kD_mkernel(graph, n, nedges_graph, d_coords, dim, smart_ini, model, maxi);
+			return stress_majorization_kD_mkernel(graph, n, nedges_graph, d_coords, nodes, dim, smart_ini, model, maxi);
 		}
 
 		if (levels_gap>0) {
@@ -144,7 +145,7 @@ stress_majorization_with_hierarchy(
 		}
 	}
 	else {
-        initLayout(graph, n, dim, d_coords);
+        initLayout(graph, n, dim, d_coords, nodes);
 		compute_hierarchy(graph, n, abs_tol, relative_tol, NULL, &ordering, &levels, &num_levels);		
 	}
     if (n == 1) return 0;
