@@ -1,4 +1,4 @@
-/* $Id: neatoinit.c,v 1.36 2008/03/03 23:01:51 ellson Exp $ $Revision: 1.36 $ */
+/* $Id: neatoinit.c,v 1.45 2008/05/21 15:21:47 erg Exp $ $Revision: 1.45 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -43,23 +43,14 @@ static int Pack;		/* If >= 0, layout components separately and pack together
 				 */
 static char *cc_pfx = "_neato_cc";
 
-void neato_nodesize(node_t * n, boolean flip)
-{
-    int w;
-
-    w = ND_xsize(n) = POINTS(ND_width(n));
-    ND_lw_i(n) = ND_rw_i(n) = w / 2;
-    ND_ht_i(n) = ND_ysize(n) = POINTS(ND_height(n));
-}
-
 void neato_init_node(node_t * n)
 {
     common_init_node(n);
     ND_pos(n) = N_NEW(GD_ndim(n->graph), double);
-    neato_nodesize(n, GD_flip(n->graph));
+    gv_nodesize(n, GD_flip(n->graph));
 }
 
-void neato_init_edge(edge_t * e)
+static void neato_init_edge(edge_t * e)
 {
     common_init_edge(e);
 
@@ -124,7 +115,7 @@ int user_pos(attrsym_t * posptr, attrsym_t * pinptr, node_t * np, int nG)
     return FALSE;
 }
 
-void neato_init_node_edge(graph_t * g)
+static void neato_init_node_edge(graph_t * g)
 {
     node_t *n;
     edge_t *e;
@@ -144,36 +135,7 @@ void neato_init_node_edge(graph_t * g)
     }
 }
 
-void neato_cleanup_node(node_t * n)
-{
-    if (ND_shape(n)) {
-	ND_shape(n)->fns->freefn(n);
-    }
-    free(ND_pos(n));
-    free_label(ND_label(n));
-    memset(&(n->u), 0, sizeof(Agnodeinfo_t));
-}
-
-void neato_free_splines(edge_t * e)
-{
-    int i;
-    if (ED_spl(e)) {
-	for (i = 0; i < ED_spl(e)->size; i++)
-	    free(ED_spl(e)->list[i].list);
-	free(ED_spl(e)->list);
-	free(ED_spl(e));
-    }
-    ED_spl(e) = NULL;
-}
-
-void neato_cleanup_edge(edge_t * e)
-{
-    neato_free_splines(e);
-    free_label(ED_label(e));
-    memset(&(e->u), 0, sizeof(Agedgeinfo_t));
-}
-
-void neato_cleanup_graph(graph_t * g)
+static void neato_cleanup_graph(graph_t * g)
 {
     if (Nop || (Pack < 0))
 	free_scan_graph(g);
@@ -187,9 +149,9 @@ void neato_cleanup(graph_t * g)
 
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
-	    neato_cleanup_edge(e);
+	    gv_cleanup_edge(e);
 	}
-	neato_cleanup_node(n);
+	gv_cleanup_node(n);
     }
     neato_cleanup_graph(g);
 }
@@ -349,7 +311,7 @@ static int user_spline(attrsym_t * E_pos, edge_t * e)
 	npts = numFields((unsigned char *) pos);	/* count potential points */
 	n = npts;
 	if ((n < 4) || (n % 3 != 1)) {
-	    neato_free_splines(e);
+	    gv_free_splines(e);
 	    return 0;
 	}
 	ps = ALLOC(n, 0, point);
@@ -358,7 +320,7 @@ static int user_spline(attrsym_t * E_pos, edge_t * e)
 	    i = sscanf(pos, "%lf,%lf%n", &x, &y, &nc);
 	    if (i < 2) {
 		free(ps);
-		neato_free_splines(e);
+		gv_free_splines(e);
 		return 0;
 	    }
 	    pos = pos + nc;
@@ -649,8 +611,10 @@ int init_nop(Agraph_t * g, int adjust)
     if (adjust && Nop == 1)
 	adjustNodes(g);
 
-    /* If g does not have a good "bb" attribute, compute it. */
-    if (!chkBB(g, G_bb))
+    /* If g does not have a good "bb" attribute or we adjusted the nodes, 
+     * compute it. 
+     */
+    if (!chkBB(g, G_bb) || (adjust && Nop == 1))
 	compute_bb(g);
 
     /* At this point, all bounding boxes should be correctly defined.
@@ -676,7 +640,7 @@ int init_nop(Agraph_t * g, int adjust)
     return 0;
 }
 
-void neato_init_graphn(Agraph_t * g, int dfltdim)
+static void neato_init_graphn(Agraph_t * g, int dfltdim)
 {
     setEdgeType (g, ET_LINE);
     GD_ndim(g->root) = late_int(g, agfindattr(g, "dim"), dfltdim, 2);
@@ -684,7 +648,7 @@ void neato_init_graphn(Agraph_t * g, int dfltdim)
     neato_init_node_edge(g);
 }
 
-void neato_init_graph(Agraph_t * g)
+static void neato_init_graph(Agraph_t * g)
 {
     neato_init_graphn(g, 2);
 }
@@ -762,7 +726,7 @@ static int checkEdge(PointMap * pm, edge_t * ep, int idx)
  * dfs for breaking cycles in vtxdata
  */
 static void
-dfsCycle (vtx_data* graph, int i,int mode)
+dfsCycle (vtx_data* graph, int i,int mode, node_t* nodes[])
 {
     node_t *np, *hp;
     int j, e, f;
@@ -771,20 +735,20 @@ dfsCycle (vtx_data* graph, int i,int mode)
      */
     double x = (mode==MODE_IPSEP?-1.0:1.0);
 
-    np = graph[i].np;
+    np = nodes[i];
     ND_mark(np) = TRUE;
     ND_onstack(np) = TRUE;
     for (e = 1; e < graph[i].nedges; e++) {
 	if (graph[i].edists[e] == 1.0) continue;  /* in edge */
 	j = graph[i].edges[e];
-	hp = graph[j].np;
+	hp = nodes[j];
 	if (ND_onstack(hp)) {  /* back edge: reverse it */
             graph[i].edists[e] = x;
             for (f = 1; (f < graph[j].nedges) &&(graph[j].edges[f] != i); f++) ;
             assert (f < graph[j].nedges);
             graph[j].edists[f] = -1.0;
         }
-	else if (ND_mark(hp) == FALSE) dfsCycle(graph, j, mode);
+	else if (ND_mark(hp) == FALSE) dfsCycle(graph, j, mode, nodes);
 
     }
     ND_onstack(np) = FALSE;
@@ -794,19 +758,19 @@ dfsCycle (vtx_data* graph, int i,int mode)
  * Do a dfs of the vtx_data, looking for cycles, reversing edges.
  */
 static void
-acyclic (vtx_data* graph, int nv, int mode)
+acyclic (vtx_data* graph, int nv, int mode, node_t* nodes[])
 {
     int i;
     node_t* np;
 
     for (i = 0; i < nv; i++) {
-	np = graph[i].np;
+	np = nodes[i];
 	ND_mark(np) = FALSE;
 	ND_onstack(np) = FALSE;
     }
     for (i = 0; i < nv; i++) {
-	if (ND_mark(graph[i].np)) continue;
-	dfsCycle (graph, i, mode);	
+	if (ND_mark(nodes[i])) continue;
+	dfsCycle (graph, i, mode, nodes);	
     }
 
 }
@@ -830,9 +794,10 @@ acyclic (vtx_data* graph, int nv, int mode)
  * the graph is acyclic.
  *
  */
-static vtx_data *makeGraphData(graph_t * g, int nv, int *nedges, int mode, int model)
+static vtx_data *makeGraphData(graph_t * g, int nv, int *nedges, int mode, int model, node_t*** nodedata)
 {
     vtx_data *graph;
+    node_t** nodes;
     int ne = agnedges(g);	/* upper bound */
     int *edges;
     float *ewgts = NULL;
@@ -862,6 +827,7 @@ static vtx_data *makeGraphData(graph_t * g, int nv, int *nedges, int mode, int m
 	haveDir = FALSE;
 
     graph = N_GNEW(nv, vtx_data);
+    nodes = N_GNEW(nv, node_t*);
     edges = N_GNEW(2 * ne + nv, int);	/* reserve space for self loops */
     if (haveLen || haveDir)
 	ewgts = N_GNEW(2 * ne + nv, float);
@@ -878,7 +844,7 @@ static vtx_data *makeGraphData(graph_t * g, int nv, int *nedges, int mode, int m
 	int j = 1;		/* index of neighbors */
 	clearPM(ps);
 	assert(ND_id(np) == i);
-	graph[i].np = np;
+	nodes[i] = np;
 	graph[i].edges = edges++;	/* reserve space for the self loop */
 	if (haveLen || haveDir)
 	    graph[i].ewgts = ewgts++;
@@ -944,7 +910,7 @@ static vtx_data *makeGraphData(graph_t * g, int nv, int *nedges, int mode, int m
 #ifdef DIGCOLA
     if (haveDir) {
     /* Make graph acyclic */
-	acyclic (graph, nv, mode);
+	acyclic (graph, nv, mode, nodes);
     }
 #endif
 
@@ -974,29 +940,14 @@ static vtx_data *makeGraphData(graph_t * g, int nv, int *nedges, int mode, int m
     }
 
     *nedges = ne;
+    if (nodedata)
+	*nodedata = nodes;
+    else
+	free (nodes);
     freePM(ps);
     return graph;
 }
 
-static void freeGraphData(vtx_data * graph)
-{
-    if (graph != NULL) {
-	if (graph[0].edges != NULL)
-	    free(graph[0].edges);
-	if (graph[0].ewgts != NULL)
-	    free(graph[0].ewgts);
-#ifdef UNIMPLEMENTED
-	if (graph[0].elens != NULL)
-	    free(graph[0].elens);
-#endif
-#ifdef USE_STYLES
-	if (graph[0].styles != NULL)
-	    free(graph[0].styles);
-#endif
-	free(graph);
-    }
-}
-
 static void initRegular(graph_t * G, int nG)
 {
     double a, da;
@@ -1136,6 +1087,8 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
     int i;
     node_t *v;
     vtx_data *gp;
+    node_t** nodes;
+    expand_t margin;
 
     int init;
 
@@ -1151,7 +1104,7 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
 	fprintf(stderr, "convert graph: ");
 	start_timer();
     }
-    gp = makeGraphData(g, nv, &ne, mode, model);
+    gp = makeGraphData(g, nv, &ne, mode, model, &nodes);
 
     if (Verbose) {
 	fprintf(stderr, "%d nodes %.2f sec\n", nv, elapsed_sec());
@@ -1161,7 +1114,7 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
     if (mode != MODE_MAJOR) {
         double lgap = late_double(g, agfindattr(g, "levelsgap"), 0.0, -MAXDOUBLE);
         if (mode == MODE_HIER) {        
-            stress_majorization_with_hierarchy(gp, nv, ne, coords, Ndim,
+            stress_majorization_with_hierarchy(gp, nv, ne, coords, nodes, Ndim,
                        (init == INIT_SELF), model, MaxIter, lgap);
         } 
 #ifdef IPSEPCOLA
@@ -1207,26 +1160,28 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
                     fprintf(stderr,"Using Mosek for constraint optimization...\n");
             }
 #endif /* MOSEK */
-            if ((str = agget(g, "sep")) && 
-                (i = sscanf(str, "%lf,%lf", &opt.gap.x, &opt.gap.y))) {
-		    if (i == 1) opt.gap.y = opt.gap.x;
-                    if(Verbose)
-                        fprintf(stderr,"gap=%f,%f\n",opt.gap.x,opt.gap.y);
-            }
-            else opt.gap.x = opt.gap.y = 0;
+	    margin = sepFactor (g);
+ 	    /* Multiply by 2 since opt.gap is the gap size, not the margin */
+	    if (margin.doAdd) {
+		opt.gap.x = 2.0*PS2INCH(margin.x);
+		opt.gap.y = 2.0*PS2INCH(margin.y);
+	    }
+            else opt.gap.x = opt.gap.y = 2.0*PS2INCH(DFLT_MARGIN);
+	    if(Verbose)
+		fprintf(stderr,"gap=%f,%f\n",opt.gap.x,opt.gap.y);
             for (i=0, v = agfstnode(g); v; v = agnxtnode(g, v),i++) {
                 nsize[i].x = ND_width(v);
                 nsize[i].y = ND_height(v);
             }
 
-            stress_majorization_cola(gp, nv, ne, coords, Ndim, model, MaxIter, &opt);
+            stress_majorization_cola(gp, nv, ne, coords, nodes, Ndim, model, MaxIter, &opt);
 	    freeClusterData(cs);
         }
 #endif
     }
     else
 #endif
-	stress_majorization_kD_mkernel(gp, nv, ne, coords, Ndim,
+	stress_majorization_kD_mkernel(gp, nv, ne, coords, nodes, Ndim,
 				   (init == INIT_SELF), model, MaxIter);
 
     /* store positions back in nodes */
@@ -1240,6 +1195,7 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
     freeGraphData(gp);
     free(coords[0]);
     free(coords);
+    free(nodes);
 }
 
 static void subset_model(Agraph_t * G, int nG)
@@ -1248,7 +1204,7 @@ static void subset_model(Agraph_t * G, int nG)
     DistType **Dij;
     vtx_data *gp;
 
-    gp = makeGraphData(G, nG, &ne, MODE_KK, MODEL_SUBSET);
+    gp = makeGraphData(G, nG, &ne, MODE_KK, MODEL_SUBSET, NULL);
     Dij = compute_apsp_artifical_weights(gp, nG);
     for (i = 0; i < nG; i++) {
 	for (j = 0; j < nG; j++) {
