@@ -1,4 +1,4 @@
-/* $Id: poly.h,v 1.2 2005/02/24 00:57:33 ellson Exp $ $Revision: 1.2 $ */
+/* $Id: poly.h,v 1.3 2008/04/08 21:34:51 erg Exp $ $Revision: 1.3 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,8 +18,6 @@
 extern "C" {
 #endif
 
-
-
 #ifndef POLY_H
 #define POLY_H
 
@@ -35,7 +33,8 @@ extern "C" {
 
     extern void polyFree(void);
     extern int polyOverlap(Point, Poly *, Point, Poly *);
-    extern void makePoly(Poly *, Agnode_t *, double);
+    extern void makePoly(Poly *, Agnode_t *, float, float);
+    extern void makeAddPoly(Poly *, Agnode_t *, float, float);
     extern void breakPoly(Poly *);
 
 #endif
