@@ -1,4 +1,4 @@
-/* $Id: quad_prog_solve.c,v 1.5 2006/04/28 20:33:44 ellson Exp $ $Revision: 1.5 $ */
+/* $Id: quad_prog_solve.c,v 1.6 2006/12/07 22:49:37 erg Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -124,7 +124,7 @@ constrained_majorization_new(CMajEnv * e, float *b, float **coords,
     int num_levels = e->num_levels;
     int i, j;
     float new_place_i;
-    bool converged = false;
+    boolean converged = FALSE;
     float upper_bound, lower_bound;
     int node;
     int left, right;
@@ -186,7 +186,7 @@ constrained_majorization_new(CMajEnv * e, float *b, float **coords,
     }
 
     for (counter = 0; counter < max_iterations && !converged; counter++) {
-	converged = true;
+	converged = TRUE;
 	lower_bound = -1e9;	/* no lower bound for first level */
 	for (left = 0; left < n; left = right) {
 	    int best_i;
@@ -435,7 +435,7 @@ int constrained_majorization_gradient_projection(CMajEnv * e,
     int *ordering = e->ordering;
     int *levels = e->levels;
     int num_levels = e->num_levels;
-    bool converged = false;
+    boolean converged = FALSE;
     float *g = e->fArray1;
     float *old_place = e->fArray2;
     float *d = e->fArray4;
@@ -462,7 +462,7 @@ int constrained_majorization_gradient_projection(CMajEnv * e,
     for (counter = 0; counter < max_iterations && !converged; counter++) {
 	float alpha;
 	float numerator = 0, denominator = 0, r;
-	converged = true;
+	converged = TRUE;
 	/* find steepest descent direction */
 	for (i = 0; i < e->n; i++) {
 	    old_place[i] = place[i];
@@ -506,9 +506,9 @@ int constrained_majorization_gradient_projection(CMajEnv * e,
 							e->lev[u]), w = 2;
 		float avgPos = sum / w;
 		float pos;
-		bool finished;
+		boolean finished;
 		do {
-		    finished = true;
+		    finished = TRUE;
 		    if (ui < endOfLevel) {
 			u = ordering[ui];
 			pos = place[u] - levels_gap * e->lev[u];
@@ -517,7 +517,7 @@ int constrained_majorization_gradient_projection(CMajEnv * e,
 			    w++;
 			    sum += pos;
 			    avgPos = sum / w;
-			    finished = false;
+			    finished = FALSE;
 			}
 		    }
 
@@ -529,7 +529,7 @@ int constrained_majorization_gradient_projection(CMajEnv * e,
 			    w++;
 			    sum += pos;
 			    avgPos = sum / w;
-			    finished = false;
+			    finished = FALSE;
 			}
 		    }
 		} while (!finished);
@@ -593,7 +593,7 @@ int constrained_majorization_gradient_projection(CMajEnv * e,
 	prev_stress = stress;
 #endif
 	if (test > quad_prog_tol) {
-	    converged = false;
+	    converged = FALSE;
 	}
     }
 #ifdef CONMAJ_LOGGING
@@ -619,7 +619,7 @@ constrained_majorization_new_with_gaps(CMajEnv * e, float *b,
     int *levels = e->levels;
     int num_levels = e->num_levels;
     float new_place_i;
-    bool converged = false;
+    boolean converged = FALSE;
     float upper_bound, lower_bound;
     int node;
     int left, right;
@@ -679,7 +679,7 @@ constrained_majorization_new_with_gaps(CMajEnv * e, float *b,
     gap = e->fArray4;
 
     for (counter = 0; counter < max_iterations && !converged; counter++) {
-	converged = true;
+	converged = TRUE;
 	lower_bound = -1e9;	/* no lower bound for first level */
 	for (left = 0; left < n; left = right) {
 	    int best_i;
