@@ -1,4 +1,4 @@
-/* $Id: sfhdr.h,v 1.4 2008/02/22 14:21:42 glenlow Exp $ $Revision: 1.4 $ */
+/* $Id: sfhdr.h,v 1.5 2008/04/23 17:16:28 ellson Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -493,7 +493,7 @@ extern "C" {
 	    if((lv = localeconv())) \
 	    { if(lv->decimal_point && lv->decimal_point[0]) \
 	    	*(decimal) = lv->decimal_point[0]; \
-	      if(thousand && lv->thousands_sep && lv->thousands_sep[0]) \
+	      if(thousand != NULL && lv->thousands_sep && lv->thousands_sep[0]) \
 	    	*(thousand) = lv->thousands_sep[0]; \
 	    } \
 	  } \
