@@ -1,4 +1,4 @@
-/* $Id: sfio.h,v 1.1.1.1 2004/12/23 04:04:09 ellson Exp $ $Revision: 1.1.1.1 $ */
+/* $Id: sfio.h,v 1.3 2007/05/11 17:06:35 erg Exp $ $Revision: 1.3 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -277,6 +277,9 @@ extern "C" {
 
      _BEGIN_EXTERNS_ extern ssize_t _Sfi;
 
+#if !_BLD_sfio && defined(GVDLL)
+#define extern	__declspec(dllimport)
+#endif
 /* standard in/out/err streams */
     extern Sfio_t *sfstdin;
     extern Sfio_t *sfstdout;
@@ -284,6 +287,7 @@ extern "C" {
     extern Sfio_t _Sfstdin;
     extern Sfio_t _Sfstdout;
     extern Sfio_t _Sfstderr;
+#undef extern
 
 #if _DLL && _DLL_INDIRECT_DATA
 /* The Uwin shared library environment requires these to be defined
