@@ -33,13 +33,12 @@
 #include <math.h>
 #include <time.h>
 #include "matrix_ops.h"
-#include "hierarchy.h"
+/* #include "hierarchy.h" */
+#include "delaunay.h"
 #include "memory.h"
 #include "arith.h"
 
-static double distortion_factor = 1.0;
-
-static double *compute_densities(vtx_data * graph, int n, double *x,
+static double *compute_densities(v_data * graph, int n, double *x,
 				 double *y)
 {
 // compute density of every node by calculating the average edge length in a 2-D layout
@@ -60,7 +59,7 @@ static double *compute_densities(vtx_data * graph, int n, double *x,
     return densities;
 }
 
-static double *recompute_densities(vtx_data * graph, int n, double *x,
+static double *recompute_densities(v_data * graph, int n, double *x,
 				   double *densities)
 {
 // compute density of every node by calculating the average edge length in a 1-D layout
@@ -84,9 +83,10 @@ static double *smooth_vec(double *vec, int *ordering, int n, int interval,
 {
 // smooth 'vec' by setting each components to the average of is 'interval'-neighborhood in 'ordering'
     int len, i, n1;
+	double sum;
     smoothed_vec = RALLOC(n, smoothed_vec, double);
     n1 = MIN(1 + interval, n);
-    double sum = 0;
+    sum = 0;
     for (i = 0; i < n1; i++) {
 	sum += vec[ordering[i]];
     }
@@ -118,11 +118,11 @@ static double *smooth_vec(double *vec, int *ordering, int n, int interval,
 /* quicksort_place:
  * Available in lib/neatogen.
  */
-static void
-split_by_place(double *place, int *nodes, int first, int last, int *middle)
+static int
+split_by_place(double *place, int *nodes, int first, int last)
 {
-    unsigned int splitter =
-	rand() * ((unsigned) (last - first)) / RAND_MAX + (unsigned) first;
+    int middle;
+    unsigned int splitter=((unsigned int)rand()|((unsigned int)rand())<<16)%(unsigned int)(last-first+1)+(unsigned int)first;
     int val;
     double place_val;
     int left = first + 1;
@@ -137,7 +137,10 @@ split_by_place(double *place, int *nodes, int first, int last, int *middle)
     while (left < right) {
 	while (left < right && place[nodes[left]] <= place_val)
 	    left++;
-	while (left < right && place[nodes[right]] >= place_val)
+        /* use here ">" and not ">=" to enable robustness
+         * by ensuring that ALL equal values move to the same side
+         */
+	while (left < right && place[nodes[right]] > place_val)
 	    right--;
 	if (left < right) {
 	    temp = nodes[left];
@@ -148,28 +151,51 @@ split_by_place(double *place, int *nodes, int first, int last, int *middle)
 
 	}
     }
-    /* in this point either, left==right (meeting), or left=right+1 (because of (1)) */
-    /* we have to decide to which part the meeting point (or left) belongs. */
+    /* at this point either, left==right (meeting), or 
+     * left=right+1 (because of (1)) 
+     * we have to decide to which part the meeting point (or left) belongs.
+     *
+     * notice that always left>first, because of its initialization
+     */
     if (place[nodes[left]] > place_val)
-	left = left - 1;	/* notice that always left>first, because of its initialization */
-    *middle = left;
-    nodes[first] = nodes[*middle];
-    nodes[*middle] = val;
+	left = left - 1;
+    middle = left;
+    nodes[first] = nodes[middle];
+    nodes[middle] = val;
+    return middle;
+}
+
+static int 
+sorted_place(double * place, int * ordering, int first, int last)
+{
+    int i, isSorted = 1; 
+    for (i=first+1; i<=last && isSorted; i++) {
+        if (place[ordering[i-1]]>place[ordering[i]]) {
+            isSorted = 0;
+        }
+    }
+    return isSorted;
 }
 
 void quicksort_place(double *place, int *ordering, int first, int last)
 {
     if (first < last) {
-	int middle;
-	split_by_place(place, ordering, first, last, &middle);
-	quicksort_place(place, ordering, first, middle - 1);
-	quicksort_place(place, ordering, middle + 1, last);
+	int middle = split_by_place(place, ordering, first, last);
+        /* Checking for "already sorted" dramatically improves running time 
+	 * and robustness (against uneven recursion) when not all values are 
+         * distinct (thefore we expect emerging chunks of equal values)
+	 * it never increased running time even when values were distinct
+         */
+	if (!sorted_place(place,ordering,first,middle-1))
+	    quicksort_place(place,ordering,first,middle-1);
+	if (!sorted_place(place,ordering,middle+1,last))
+	    quicksort_place(place,ordering,middle+1,last);
     }
 }
 
 static void
-rescaleLayout(vtx_data * graph, int n, double *x_coords, double *y_coords,
-	      int interval)
+rescaleLayout(v_data * graph, int n, double *x_coords, double *y_coords,
+	      int interval, double distortion)
 {
     // Rectlinear distortion - auxilliary function
     int i;
@@ -185,15 +211,15 @@ rescaleLayout(vtx_data * graph, int n, double *x_coords, double *y_coords,
     }
 
     // just to make milder behavior:
-    if (distortion_factor >= 0) {
-	factor = sqrt(distortion_factor);
+    if (distortion >= 0) {
+	factor = sqrt(distortion);
     } else {
-	factor = -sqrt(-distortion_factor);
+	factor = -sqrt(-distortion);
     }
 
     quicksort_place(x_coords, ordering, 0, n - 1);
     densities = recompute_densities(graph, n, x_coords, densities);
-    smooth_vec(densities, ordering, n, interval, smoothed_densities);
+    smoothed_densities = smooth_vec(densities, ordering, n, interval, smoothed_densities);
     cpvec(copy_coords, 0, n - 1, x_coords);
     for (i = 1; i < n; i++) {
 	x_coords[ordering[i]] =
@@ -204,7 +230,7 @@ rescaleLayout(vtx_data * graph, int n, double *x_coords, double *y_coords,
 
     quicksort_place(y_coords, ordering, 0, n - 1);
     densities = recompute_densities(graph, n, y_coords, densities);
-    smooth_vec(densities, ordering, n, interval, smoothed_densities);
+    smoothed_densities = smooth_vec(densities, ordering, n, interval, smoothed_densities);
     cpvec(copy_coords, 0, n - 1, y_coords);
     for (i = 1; i < n; i++) {
 	y_coords[ordering[i]] =
@@ -221,19 +247,19 @@ rescaleLayout(vtx_data * graph, int n, double *x_coords, double *y_coords,
 
 void
 rescale_layout(double *x_coords, double *y_coords,
-	       int n, int interval, int ClientWidth, int ClientHeight,
-	       int margin)
+	       int n, int interval, double width, double height,
+	       double margin, double distortion)
 {
     // Rectlinear distortion - main function
     int i;
     double minX, maxX, minY, maxY;
-    double aspect_ratio = (maxX - minX) / (maxY - minY);
-    vtx_data *graph;
+    double aspect_ratio;
+    v_data *graph;
     double scaleX;
     double scale_ratio;
 
-    ClientWidth -= 2 * margin;
-    ClientHeight -= 2 * margin;
+    width -= 2 * margin;
+    height -= 2 * margin;
 
     // compute original aspect ratio
     minX = maxX = x_coords[0];
@@ -252,7 +278,7 @@ rescale_layout(double *x_coords, double *y_coords,
 
     // construct mutual neighborhood graph
     graph = UG_graph(x_coords, y_coords, n, 0);
-    rescaleLayout(graph, n, x_coords, y_coords, interval);
+    rescaleLayout(graph, n, x_coords, y_coords, interval, distortion);
     free(graph[0].edges);
     free(graph);
 
@@ -284,8 +310,8 @@ rescale_layout(double *x_coords, double *y_coords,
 
     // scale the layout to fit full drawing area:
     scale_ratio =
-	MIN((ClientWidth) / (aspect_ratio * (maxY - minY)),
-	    (ClientHeight) / (maxY - minY));
+	MIN((width) / (aspect_ratio * (maxY - minY)),
+	    (height) / (maxY - minY));
     for (i = 0; i < n; i++) {
 	x_coords[i] *= scale_ratio;
 	y_coords[i] *= scale_ratio;
@@ -300,9 +326,9 @@ rescale_layout(double *x_coords, double *y_coords,
 #define DIST(x1,y1,x2,y2) (sqrt((x1-x2)*(x1-x2)+(y1-y2)*(y1-y2)))
 
 static void
-rescale_layout_polarFocus(vtx_data * graph, int n,
-			  double *x_coords, double *y_coords,
-			  double x_focus, double y_focus, int interval)
+rescale_layout_polarFocus(v_data * graph, int n,
+	  double *x_coords, double *y_coords,
+	  double x_focus, double y_focus, int interval, double distortion)
 {
     // Polar distortion - auxilliary function
     int i;
@@ -324,25 +350,24 @@ rescale_layout_polarFocus(vtx_data * graph, int n,
     quicksort_place(distances, ordering, 0, n - 1);
 
     densities = compute_densities(graph, n, x_coords, y_coords);
-    smooth_vec(densities, ordering, n, interval, smoothed_densities);
+    smoothed_densities = smooth_vec(densities, ordering, n, interval, smoothed_densities);
 
     // rescale distances
-    if (distortion_factor < 1.01 && distortion_factor > 0.99) {
+    if (distortion < 1.01 && distortion > 0.99) {
 	for (i = 1; i < n; i++) {
 	    distances[ordering[i]] =
 		distances[ordering[i - 1]] + (orig_distances[ordering[i]] -
 					      orig_distances[ordering
 							     [i -
-							      1]]) /
-		smoothed_densities[ordering[i]];
+							      1]]) / smoothed_densities[ordering[i]];
 	}
     } else {
 	double factor;
 	// just to make milder behavior:
-	if (distortion_factor >= 0) {
-	    factor = sqrt(distortion_factor);
+	if (distortion >= 0) {
+	    factor = sqrt(distortion);
 	} else {
-	    factor = -sqrt(-distortion_factor);
+	    factor = -sqrt(-distortion);
 	}
 	for (i = 1; i < n; i++) {
 	    distances[ordering[i]] =
@@ -375,19 +400,19 @@ rescale_layout_polarFocus(vtx_data * graph, int n,
 void
 rescale_layout_polar(double *x_coords, double *y_coords,
 		     double *x_foci, double *y_foci, int num_foci,
-		     int n, int interval, int ClientWidth,
-		     int ClientHeight, int margin)
+		     int n, int interval, double width,
+		     double height, double margin, double distortion)
 {
     // Polar distortion - main function
     int i;
     double minX, maxX, minY, maxY;
     double aspect_ratio;
-    vtx_data *graph;
+    v_data *graph;
     double scaleX;
     double scale_ratio;
 
-    ClientWidth -= 2 * margin;
-    ClientHeight -= 2 * margin;
+    width -= 2 * margin;
+    height -= 2 * margin;
 
     // compute original aspect ratio
     minX = maxX = x_coords[0];
@@ -409,7 +434,7 @@ rescale_layout_polar(double *x_coords, double *y_coords,
 
     if (num_foci == 1) {	// accelerate execution of most common case
 	rescale_layout_polarFocus(graph, n, x_coords, y_coords, x_foci[0],
-				  y_foci[0], interval);
+				  y_foci[0], interval, distortion);
     } else {
 	// average-based rescale
 	double *final_x_coords = N_NEW(n, double);
@@ -423,7 +448,7 @@ rescale_layout_polar(double *x_coords, double *y_coords,
 	    cpvec(cp_x_coords, 0, n - 1, x_coords);
 	    cpvec(cp_y_coords, 0, n - 1, y_coords);
 	    rescale_layout_polarFocus(graph, n, cp_x_coords, cp_y_coords,
-				      x_foci[i], y_foci[i], interval);
+				      x_foci[i], y_foci[i], interval, distortion);
 	    scadd(final_x_coords, 0, n - 1, 1.0 / num_foci, cp_x_coords);
 	    scadd(final_y_coords, 0, n - 1, 1.0 / num_foci, cp_y_coords);
 	}
@@ -465,8 +490,8 @@ rescale_layout_polar(double *x_coords, double *y_coords,
 
     // scale the layout to fit full drawing area:
     scale_ratio =
-	MIN((ClientWidth) / (aspect_ratio * (maxY - minY)),
-	    (ClientHeight) / (maxY - minY));
+	MIN((width) / (aspect_ratio * (maxY - minY)),
+	    (height) / (maxY - minY));
     for (i = 0; i < n; i++) {
 	x_coords[i] *= scale_ratio;
 	y_coords[i] *= scale_ratio;
