@@ -1,4 +1,4 @@
-/* $Id: vmbest.c,v 1.2 2007/05/03 23:19:43 erg Exp $ $Revision: 1.2 $ */
+/* $Id: vmbest.c,v 1.3 2008/02/22 14:21:42 glenlow Exp $ $Revision: 1.3 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -16,6 +16,11 @@
 
 #include	"vmhdr.h"
 
+/* for VirtualAlloc and friends */
+#if defined(_WIN32)
+#include <windows.h>
+#endif
+
 /*	Best-fit allocation method. This is based on a best-fit strategy
 **	using a splay tree for storage of lists of free blocks of the same
 **	size. Recent free blocks may be cached for fast reuse.
