@@ -1,4 +1,4 @@
-/* $Id: GVDocument.h,v 1.2 2008/02/11 12:34:07 glenlow Exp $ $Revision: 1.2 $ */
+/* $Id: GVDocument.h,v 1.5 2008/05/27 14:26:29 glenlow Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,10 +17,12 @@
 #import <Foundation/Foundation.h>
 #import <AppKit/AppKit.h>
 
+@class GVExportViewController;
 @class GVGraph;
 
 @interface GVDocument : NSDocument
 {
+	GVExportViewController *_exporter;
 	GVGraph *_graph;
 }
 
@@ -33,6 +35,14 @@
 
 - (void)makeWindowControllers;
 
+- (void)setPrintInfo:(NSPrintInfo *)printInfo;
+
+- (IBAction)exportDocument:(id)sender;
+- (void)exporterDidEnd:(GVExportViewController *)exporter;
+
+- (void)fileDidChange:(NSString *)path;
+- (void)graphDidChange:(NSNotification *)notification;
+
 - (void)dealloc;
 
 @end
