@@ -1,4 +1,4 @@
-/* $Id: GVGraphDefaultAttributes.h,v 1.2 2008/02/13 05:08:09 glenlow Exp $ $Revision: 1.2 $ */
+/* $Id: GVGraphDefaultAttributes.h,v 1.3 2008/03/27 11:55:33 glenlow Exp $ $Revision: 1.3 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -24,13 +24,10 @@
 @interface GVGraphDefaultAttributes : NSMutableDictionary
 {
 	GVGraph *_graph;
-	Agdict_t *_defaultAttributes;
-	Agsym_t *(*_attributeDeclaration)(Agraph_t *, char *, char *);
+	void *_proto;
 }
 
-@property(readonly) NSString *name;
-
-- (id)initWithGraph:(GVGraph *)graph defaultAttributes:(Agdict_t *)defaultAttributes attributeDeclaration:(Agsym_t *(*)(Agraph_t *, char *, char *))attributeDeclaration;
+- (id)initWithGraph:(GVGraph *)graph prototype:(void *)proto;
 
 /* dictionary primitive methods */
 - (NSUInteger)count;
