@@ -1,4 +1,4 @@
-/* $Id: GVWindowController.h,v 1.2 2008/02/11 12:34:07 glenlow Exp $ $Revision: 1.2 $ */
+/* $Id: GVWindowController.h,v 1.6 2008/05/27 15:23:46 glenlow Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,22 +18,26 @@
 #import <AppKit/AppKit.h>
 #import <Quartz/Quartz.h>
 
-@class GVGraph;
-
-@interface GVWindowController : NSWindowController
+@interface GVWindowController : NSWindowController <NSUserInterfaceValidations>
 {
 	IBOutlet PDFView *documentView;
-	
-	GVGraph *_graph;
 }
 
-@property(readonly) GVGraph *graph;
-
 - (id)init;
 - (void)setDocument: (NSDocument *)document;
 - (void)awakeFromNib;
 
-- (void)graphDidChange:(NSNotification*)notification;
+- (void)graphDocumentDidChange:(NSNotification*)notification;
+- (NSRect)windowWillUseStandardFrame:(NSWindow *)window defaultFrame:(NSRect)defaultFrame;
+
+- (IBAction)actualSizeView:(id)sender;
+- (IBAction)zoomInView:(id)sender;
+- (IBAction)zoomOutView:(id)sender;
+- (IBAction)zoomToFitView:(id)sender;
+
+- (IBAction)printGraphDocument:(id)sender;
+
+- (BOOL)validateUserInterfaceItem:(id <NSValidatedUserInterfaceItem>)anItem;
 
 - (void)dealloc;
 @end
