@@ -1,4 +1,4 @@
-/* $Id: gvloadimage_core.c,v 1.24 2007/12/26 16:53:24 ellson Exp $ $Revision: 1.24 $ */
+/* $Id: gvloadimage_core.c,v 1.26 2008/04/24 11:19:55 ellson Exp $ $Revision: 1.26 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -36,10 +36,11 @@ extern shape_desc *find_user_shape(char *name);
 
 typedef enum {
     FORMAT_PNG_SVG, FORMAT_GIF_SVG, FORMAT_JPEG_SVG,
-    FORMAT_PNG_XDOT, FORMAT_GIF_XDOT, FORMAT_JPEG_XDOT,
+    FORMAT_PNG_XDOT, FORMAT_GIF_XDOT, FORMAT_JPEG_XDOT, FORMAT_PS_XDOT, FORMAT_SVG_XDOT,
     FORMAT_PNG_FIG, FORMAT_GIF_FIG, FORMAT_JPEG_FIG,
     FORMAT_PNG_VRML, FORMAT_GIF_VRML, FORMAT_JPEG_VRML,
     FORMAT_PS_PS, FORMAT_PSLIB_PS, FORMAT_SVG_SVG,
+    FORMAT_PNG_DOT, FORMAT_GIF_DOT, FORMAT_JPEG_DOT, FORMAT_PS_DOT, FORMAT_SVG_DOT,
 } format_type;
 
 static void core_loadimage_svg(GVJ_t * job, usershape_t *us, boxf b, boolean filled)
@@ -47,7 +48,6 @@ static void core_loadimage_svg(GVJ_t * job, usershape_t *us, boxf b, boolean fil
     assert(job);
     assert(us);
     assert(us->name);
-    assert(us->f);
 
     gvdevice_fputs(job, "<image xlink:href=\"");
     gvdevice_fputs(job, us->name);
@@ -89,7 +89,6 @@ static void core_loadimage_fig(GVJ_t * job, usershape_t *us, boxf bf, boolean fi
     assert(job);
     assert(us);
     assert(us->name);
-    assert(us->f);
 
     BF2B(bf, b);
 
@@ -121,7 +120,6 @@ static void core_loadimage_vrml(GVJ_t * job, usershape_t *us, boxf b, boolean fi
 
     assert(us);
     assert(us->name);
-    assert(us->f);
 
     n = job->obj->u.n;
     assert(n);
@@ -135,8 +133,6 @@ static void core_loadimage_vrml(GVJ_t * job, usershape_t *us, boxf b, boolean fi
     fprintf(out, "    texture ImageTexture { url \"%s\" }\n", us->name);
     fprintf(out, "  }\n");
     fprintf(out, "}\n");
-
-
 }
 
 static void ps_freeimage(usershape_t *us)
@@ -156,7 +152,6 @@ static void core_loadimage_ps(GVJ_t * job, usershape_t *us, boxf b, boolean fill
     assert(job);
     assert(us);
     assert(us->name);
-    assert(us->f);
 
     out = job->output_file;
     assert(out);
@@ -171,10 +166,12 @@ static void core_loadimage_ps(GVJ_t * job, usershape_t *us, boxf b, boolean fill
     }
 
     if (!us->data) { /* read file into cache */
-        int fd = fileno(us->f);
+        int fd;
 	struct stat statbuf;
 
-        fseek(us->f, 0, SEEK_SET);
+	if (!gvusershape_file_access(us))
+	    return;
+	fd = fileno(us->f);
         switch (us->type) {
             case FT_PS:
             case FT_EPS:
@@ -193,6 +190,7 @@ static void core_loadimage_ps(GVJ_t * job, usershape_t *us, boxf b, boolean fill
         }
         if (us->data)
             us->datafree = ps_freeimage;
+	gvusershape_file_release(us);
     }
 
     if (us->data) {
@@ -217,7 +215,6 @@ static void core_loadimage_pslib(GVJ_t * job, usershape_t *us, boxf b, boolean f
     assert(job);
     assert(us);
     assert(us->name);
-    assert(!(us->f));
 
     out = job->output_file;
     assert(out);
@@ -247,6 +244,11 @@ static void core_loadimage_pslib(GVJ_t * job, usershape_t *us, boxf b, boolean f
     }
 }
 
+void core_loadimage_dot(GVJ_t *gvc, usershape_t *us, boxf b, boolean filled)
+{
+    /* null function - basically suppress the missing loader message */
+}
+
 static gvloadimage_engine_t engine_svg = {
     core_loadimage_svg
 };
@@ -267,6 +269,10 @@ static gvloadimage_engine_t engine_pslib = {
     core_loadimage_pslib
 };
 
+static gvloadimage_engine_t engine_dot = {
+    core_loadimage_dot
+};
+
 static gvloadimage_engine_t engine_xdot = {
     core_loadimage_xdot
 };
@@ -277,23 +283,38 @@ gvplugin_installed_t gvloadimage_core_types[] = {
     {FORMAT_JPEG_SVG, "jpeg:svg", 1, &engine_svg, NULL},
     {FORMAT_JPEG_SVG, "jpe:svg", 1, &engine_svg, NULL},
     {FORMAT_JPEG_SVG, "jpg:svg", 1, &engine_svg, NULL},
+
     {FORMAT_PNG_FIG, "png:fig", 1, &engine_fig, NULL},
     {FORMAT_GIF_FIG, "gif:fig", 1, &engine_fig, NULL},
     {FORMAT_JPEG_FIG, "jpeg:fig", 1, &engine_fig, NULL},
     {FORMAT_JPEG_FIG, "jpe:fig", 1, &engine_fig, NULL},
     {FORMAT_JPEG_FIG, "jpg:fig", 1, &engine_fig, NULL},
+
     {FORMAT_PNG_VRML, "png:vrml", 1, &engine_vrml, NULL},
     {FORMAT_GIF_VRML, "gif:vrml", 1, &engine_vrml, NULL},
     {FORMAT_JPEG_VRML, "jpeg:vrml", 1, &engine_vrml, NULL},
     {FORMAT_JPEG_VRML, "jpe:vrml", 1, &engine_vrml, NULL},
     {FORMAT_JPEG_VRML, "jpg:vrml", 1, &engine_vrml, NULL},
+
     {FORMAT_PS_PS, "ps:ps", 1, &engine_ps, NULL},
     {FORMAT_PSLIB_PS, "(lib):ps", 1, &engine_pslib, NULL},  /* for pslib */
+
+    {FORMAT_PNG_DOT, "png:dot", 1, &engine_dot, NULL},
+    {FORMAT_GIF_DOT, "gif:dot", 1, &engine_dot, NULL},
+    {FORMAT_JPEG_DOT, "jpeg:dot", 1, &engine_dot, NULL},
+    {FORMAT_JPEG_DOT, "jpe:dot", 1, &engine_dot, NULL},
+    {FORMAT_JPEG_DOT, "jpg:dot", 1, &engine_dot, NULL},
+    {FORMAT_PS_DOT, "ps:dot", 1, &engine_dot, NULL},
+    {FORMAT_SVG_DOT, "svg:dot", 1, &engine_dot, NULL},
+
     {FORMAT_PNG_XDOT, "png:xdot", 1, &engine_xdot, NULL},
     {FORMAT_GIF_XDOT, "gif:xdot", 1, &engine_xdot, NULL},
     {FORMAT_JPEG_XDOT, "jpeg:xdot", 1, &engine_xdot, NULL},
     {FORMAT_JPEG_XDOT, "jpe:xdot", 1, &engine_xdot, NULL},
     {FORMAT_JPEG_XDOT, "jpg:xdot", 1, &engine_xdot, NULL},
+    {FORMAT_PS_XDOT, "ps:xdot", 1, &engine_xdot, NULL},
+    {FORMAT_SVG_XDOT, "svg:xdot", 1, &engine_xdot, NULL},
+
     {FORMAT_SVG_SVG, "svg:svg", 1, &engine_svg, NULL},
     {0, NULL, 0, NULL, NULL}
 };
