@@ -1,4 +1,4 @@
-/* $Id: gvplugin_core.c,v 1.15 2007/09/06 17:32:55 ellson Exp $ $Revision: 1.15 $ */
+/* $Id: gvplugin_core.c,v 1.16 2008/04/25 20:06:20 ellson Exp $ $Revision: 1.16 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,33 +17,42 @@
 #include "gvplugin.h"
 
 extern gvplugin_installed_t gvdevice_dot_types;
-extern gvplugin_installed_t gvdevice_ps_types;
 extern gvplugin_installed_t gvdevice_fig_types;
-extern gvplugin_installed_t gvdevice_svg_types;
-extern gvplugin_installed_t gvdevice_vml_types;
 extern gvplugin_installed_t gvdevice_map_types;
+extern gvplugin_installed_t gvdevice_ps_types;
+extern gvplugin_installed_t gvdevice_svg_types;
+extern gvplugin_installed_t gvdevice_tk_types;
+extern gvplugin_installed_t gvdevice_vml_types;
+
 extern gvplugin_installed_t gvrender_dot_types;
-extern gvplugin_installed_t gvrender_ps_types;
 extern gvplugin_installed_t gvrender_fig_types;
-extern gvplugin_installed_t gvrender_svg_types;
-extern gvplugin_installed_t gvrender_vml_types;
 extern gvplugin_installed_t gvrender_map_types;
+extern gvplugin_installed_t gvrender_ps_types;
+extern gvplugin_installed_t gvrender_svg_types;
+extern gvplugin_installed_t gvrender_tk_types;
+extern gvplugin_installed_t gvrender_vml_types;
+
 extern gvplugin_installed_t gvloadimage_core_types;
 
 static gvplugin_api_t apis[] = {
     {API_device, &gvdevice_dot_types},
-    {API_device, &gvdevice_ps_types},
     {API_device, &gvdevice_fig_types},
-    {API_device, &gvdevice_svg_types},
-    {API_device, &gvdevice_vml_types},
     {API_device, &gvdevice_map_types},
+    {API_device, &gvdevice_ps_types},
+    {API_device, &gvdevice_svg_types},
+    {API_device, &gvdevice_tk_types},
+    {API_device, &gvdevice_vml_types},
+
     {API_render, &gvrender_dot_types},
-    {API_render, &gvrender_ps_types},
     {API_render, &gvrender_fig_types},
-    {API_render, &gvrender_svg_types},
-    {API_render, &gvrender_vml_types},
     {API_render, &gvrender_map_types},
+    {API_render, &gvrender_ps_types},
+    {API_render, &gvrender_svg_types},
+    {API_render, &gvrender_tk_types},
+    {API_render, &gvrender_vml_types},
+
     {API_loadimage, &gvloadimage_core_types},
+
     {(api_t)0, 0},
 };
 
