@@ -1,4 +1,4 @@
-/* $Id: gvrender_core_fig.c,v 1.19 2007/10/03 19:00:06 ellson Exp $ $Revision: 1.19 $ */
+/* $Id: gvrender_core_fig.c,v 1.21 2008/03/03 23:01:52 ellson Exp $ $Revision: 1.21 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -256,8 +256,12 @@ static void fig_textpara(GVJ_t * job, pointf p, textpara_t * para)
     int pen_style = 0;          /* not used */
     int font = -1;		/* init to xfig's default font */
     double font_size = para->fontsize * job->zoom;
-    double angle = job->rotation ? (PI / 2.0) : 0.0;
-    int font_flags = 4;		/* PostScript font */
+    double angle = job->rotation ? (M_PI / 2.0) : 0.0;
+    int font_flags = 6;		/* PostScript font + Special text */
+/* Special text indicates that latex markup may exist
+ * in the output - but note that dot knows nothing about latex,
+ * so the node sizes may be wrong.
+ */
     double height = 0.0;
     double length = 0.0;
 
