@@ -1,4 +1,4 @@
-/* $Id: gvrender_core_map.c,v 1.24 2007/10/03 19:00:06 ellson Exp $ $Revision: 1.24 $ */
+/* $Id: gvrender_core_map.c,v 1.25 2008/04/02 22:38:24 ellson Exp $ $Revision: 1.25 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -24,6 +24,7 @@
 #include "graph.h"
 
 extern char *xml_string(char *str);
+extern char *xml_url_string(char *str);
 
 typedef enum { FORMAT_IMAP, FORMAT_ISMAP, FORMAT_CMAP, FORMAT_CMAPX, } format_type;
 
@@ -96,7 +97,7 @@ static void map_output_shape (GVJ_t *job, map_shape_t map_shape, pointf * AF, in
         }
         if (url && url[0]) {
             gvdevice_fputs(job, " href=\"");
-	    gvdevice_fputs(job, xml_string(url));
+	    gvdevice_fputs(job, xml_url_string(url));
 	    gvdevice_fputs(job, "\"");
 	}
         if (target && target[0]) {
