@@ -1,4 +1,4 @@
-/* $Id: gvrender_core_svg.c,v 1.62 2007/11/27 20:02:32 erg Exp $ $Revision: 1.62 $ */
+/* $Id: gvrender_core_svg.c,v 1.64 2008/04/27 21:48:34 ellson Exp $ $Revision: 1.64 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -44,9 +44,10 @@
 typedef enum { FORMAT_SVG, FORMAT_SVGZ, } format_type;
 
 extern char *xml_string(char *str);
+extern char *xml_url_string(char *str);
 
 /* SVG dash array */
-static char *sdarray = "5,2";
+static char *sdasharray = "5,2";
 /* SVG dot array */
 static char *sdotarray = "1,5";
 
@@ -97,7 +98,7 @@ static void svg_grstyle(GVJ_t * job, int filled)
     if (obj->penwidth != PENWIDTH_NORMAL)
 	gvdevice_printf(job, ";stroke-width:%g", obj->penwidth);
     if (obj->pen == PEN_DASHED) {
-	gvdevice_printf(job, ";stroke-dasharray:%s", sdarray);
+	gvdevice_printf(job, ";stroke-dasharray:%s", sdasharray);
     } else if (obj->pen == PEN_DOTTED) {
 	gvdevice_printf(job, ";stroke-dasharray:%s", sdotarray);
     }
@@ -282,7 +283,7 @@ svg_begin_anchor(GVJ_t * job, char *href, char *tooltip, char *target)
 {
     gvdevice_fputs(job, "<a");
     if (href && href[0])
-	gvdevice_printf(job, " xlink:href=\"%s\"", xml_string(href));
+	gvdevice_printf(job, " xlink:href=\"%s\"", xml_url_string(href));
     if (tooltip && tooltip[0])
 	gvdevice_printf(job, " xlink:title=\"%s\"", xml_string(tooltip));
     if (target && target[0])
