@@ -1,4 +1,4 @@
-/* $Id: gvrender_core_vml.c,v 1.10 2007/10/04 10:38:14 ellson Exp $ $Revision: 1.10 $ */
+/* $Id: gvrender_core_vml.c,v 1.11 2008/02/22 14:21:43 glenlow Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -34,7 +34,7 @@ extern char *xml_string(char *str);
 
 char graphcoords[256];
 
-#ifdef WIN32
+#if defined(WIN32) && !defined(__MINGW32_VERSION)	/* MinGW already defines snprintf */
 static int
 snprintf (char *str, int n, char *fmt, ...)
 {
