@@ -1,4 +1,4 @@
-/* $Id: gvloadimage_gd.c,v 1.9 2007/10/03 19:19:29 ellson Exp $ $Revision: 1.9 $ */
+/* $Id: gvloadimage_gd.c,v 1.11 2008/03/25 16:17:45 ellson Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -43,7 +43,6 @@ static gdImagePtr gd_loadimage(GVJ_t * job, usershape_t *us)
     assert(job);
     assert(us);
     assert(us->name);
-    assert(us->f);
 
     if (us->data) {
 	if (us->datafree != gd_freeimage) {
@@ -53,7 +52,8 @@ static gdImagePtr gd_loadimage(GVJ_t * job, usershape_t *us)
 	}
     }
     if (!us->data) { /* read file into cache */
-	fseek(us->f, 0, SEEK_SET);
+	if (!gvusershape_file_access(us))
+	    return NULL;
 	switch (us->type) {
 #if 0
 	    case FT_GD:
@@ -95,6 +95,8 @@ static gdImagePtr gd_loadimage(GVJ_t * job, usershape_t *us)
 	}
         if (us->data)
 	    us->datafree = gd_freeimage;
+
+	gvusershape_file_release(us);
     }
     return (gdImagePtr)(us->data);
 }
