@@ -1,4 +1,4 @@
-/* $Id: gvplugin_gd.c,v 1.6 2006/06/24 16:51:22 ellson Exp $ $Revision: 1.6 $ */
+/* $Id: gvplugin_gd.c,v 1.10 2007/09/06 17:32:55 ellson Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -20,12 +20,18 @@ extern gvplugin_installed_t gvrender_gd_types;
 extern gvplugin_installed_t gvrender_vrml_types;
 extern gvplugin_installed_t gvtextlayout_gd_types;
 extern gvplugin_installed_t gvloadimage_gd_types;
+extern gvplugin_installed_t gvdevice_gd_types;
+extern gvplugin_installed_t gvdevice_gd_types2;
+extern gvplugin_installed_t gvdevice_vrml_types;
 
 static gvplugin_api_t apis[] = {
     {API_render, &gvrender_gd_types},
     {API_render, &gvrender_vrml_types},
     {API_textlayout, &gvtextlayout_gd_types},
     {API_loadimage, &gvloadimage_gd_types},
+    {API_device, &gvdevice_gd_types},
+    {API_device, &gvdevice_gd_types2},
+    {API_device, &gvdevice_vrml_types},
     {(api_t)0, 0},
 };
 
