@@ -1,4 +1,4 @@
-/* $Id: gvplugin_gdiplus.cpp,v 1.1 2008/02/28 04:16:40 glenlow Exp $ $Revision: 1.1 $ */
+/* $Id: gvplugin_gdiplus.cpp,v 1.2 2008/04/18 14:10:43 glenlow Exp $ $Revision: 1.2 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,13 +18,13 @@
 
 extern gvplugin_installed_t gvrender_gdiplus_types;
 // extern gvplugin_installed_t gvtextlayout_gdiplus_types;
-// extern gvplugin_installed_t gvloadimage_gdiplus_types;
+extern gvplugin_installed_t gvloadimage_gdiplus_types;
 extern gvplugin_installed_t gvdevice_gdiplus_types;
 
 static gvplugin_api_t apis[] = {
     {API_render, &gvrender_gdiplus_types},
   //  {API_textlayout, &gvtextlayout_gdiplus_types},
-  //  {API_loadimage, &gvloadimage_gdiplus_types},
+	{API_loadimage, &gvloadimage_gdiplus_types},
     {API_device, &gvdevice_gdiplus_types},
     {(api_t)0, 0},
 };
