@@ -1,4 +1,4 @@
-/* $Id: gvplugin_ming.c,v 1.1 2006/09/02 17:29:46 ellson Exp $ $Revision: 1.1 $ */
+/* $Id: gvplugin_ming.c,v 1.2 2007/08/29 19:44:01 ellson Exp $ $Revision: 1.2 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,8 +17,10 @@
 #include "gvplugin.h"
 
 extern gvplugin_installed_t gvrender_ming_types;
+extern gvplugin_installed_t gvdevice_ming_types;
 
 static gvplugin_api_t apis[] = {
+    {API_device, &gvdevice_ming_types},
     {API_render, &gvrender_ming_types},
     {(api_t)0, 0},
 };
