@@ -1,4 +1,4 @@
-/* $Id: gvrender_ming.c,v 1.8 2006/10/27 13:23:33 ellson Exp $ $Revision: 1.8 $ */
+/* $Id: gvrender_ming.c,v 1.20 2007/10/18 17:11:41 ellson Exp $ $Revision: 1.20 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -22,8 +22,20 @@
 #include <string.h>
 #include "gvplugin_render.h"
 
+/* from config.h - would conflict with ming.h definitions */
+#undef PACKAGE
+#undef PACKAGE_NAME
+#undef PACKAGE_STRING
+#undef PACKAGE_TARNAME
+#undef PACKAGE_VERSION
+#undef VERSION
+
 #include <ming.h>
 
+static char *script = 
+    "createTextField(\"greet\", 0, 0, 0, 100, 100);\n"
+    "greet.text = \"Hello, world!\";\n";
+	
 #define SWFVERSION 6
 #define SWFCOMPRESSION 9
 #define SWFFRAMERATE .5
@@ -33,6 +45,7 @@ typedef enum { FORMAT_SWF } format_type;
 static void ming_begin_job(GVJ_t * job)
 {
     SWFMovie movie;
+    SWFAction action;
 
     Ming_init();
     Ming_useSWFVersion(SWFVERSION);
@@ -41,21 +54,25 @@ static void ming_begin_job(GVJ_t * job)
     SWFMovie_setRate(movie, SWFFRAMERATE);
     SWFMovie_setDimension(movie, job->width, job->height);
 
-    job->surface = (void*) movie;
+    action = newSWFAction(script);
+    SWFMovie_add(movie, (SWFBlock)action);
+
+    job->context = (void*) movie;
 }
 
 static void ming_end_job(GVJ_t * job)
 {
-    SWFMovie movie = (SWFMovie)(job->surface);
+    SWFMovie movie = (SWFMovie)(job->context);
 
     SWFMovie_output_to_stream(movie, job->output_file);
     destroySWFMovie(movie);
-    job->surface = NULL;
+//    destroySWFAction(action);
+    job->context = NULL;
 }
 
 static void ming_begin_page(GVJ_t * job)
 {
-//    SWFMovie movie = (SWFMovie)(job->surface);
+//    SWFMovie movie = (SWFMovie)(job->context);
 
 //    SWFMovie_setNumberOfFrames(movie, job->common->viewNum + 1);
 
@@ -68,7 +85,7 @@ static void ming_begin_page(GVJ_t * job)
 
 static void ming_end_page(GVJ_t * job)
 {
-    SWFMovie movie = (SWFMovie)(job->surface);
+    SWFMovie movie = (SWFMovie)(job->context);
 
     SWFMovie_nextFrame(movie);
 }
@@ -78,14 +95,13 @@ extern char* gvconfig_libdir(void);
 
 static void ming_textpara(GVJ_t * job, pointf p, textpara_t * para)
 {
-    SWFMovie movie = (SWFMovie)(job->surface);
+    SWFMovie movie = (SWFMovie)(job->context);
     SWFTextField textfield;
     SWFDisplayItem item;
     obj_state_t *obj = job->obj;
     gvcolor_t pencolor = obj->pencolor;
     pointf offset;
     char *font_file_name;
-    FILE *font_file;
     char *libdir;
     static SWFFont font;
 
@@ -96,14 +112,7 @@ static void ming_textpara(GVJ_t * job, pointf p, textpara_t * para)
 	strcpy(font_file_name, libdir);
 	strcat(font_file_name, "/");
 	strcat(font_file_name, FONT);
-	font_file = fopen(font_file_name, "r");
-	if (font_file == NULL ) {
-	    perror(font_file_name);
-	    free(font_file_name);
-	    exit(1);
-	}
-	font = loadSWFFontFromFile(font_file);
-	fclose(font_file);
+	font = newSWFFont_fromFile(font_file_name);
 	free(font_file_name);
     }
 
@@ -139,7 +148,7 @@ static void ming_textpara(GVJ_t * job, pointf p, textpara_t * para)
 
 static void ming_ellipse(GVJ_t * job, pointf * A, int filled)
 {
-    SWFMovie movie = (SWFMovie)(job->surface);
+    SWFMovie movie = (SWFMovie)(job->context);
     SWFShape shape;
     SWFFill fill;
     SWFDisplayItem item;
@@ -149,7 +158,7 @@ static void ming_ellipse(GVJ_t * job, pointf * A, int filled)
     double rx, ry;
 
     shape = newSWFShape();
-    SWFShape_setLineStyle(shape, obj->penwidth * 20,
+    SWFShape_setLine(shape, obj->penwidth,
 	 pencolor.u.rgba[0],
 	 pencolor.u.rgba[1],
 	 pencolor.u.rgba[2],
@@ -174,7 +183,7 @@ static void ming_ellipse(GVJ_t * job, pointf * A, int filled)
 static void
 ming_polygon(GVJ_t * job, pointf * A, int n, int filled)
 {
-    SWFMovie movie = (SWFMovie)(job->surface);
+    SWFMovie movie = (SWFMovie)(job->context);
     SWFShape shape;
     SWFFill fill;
     obj_state_t *obj = job->obj;
@@ -183,7 +192,7 @@ ming_polygon(GVJ_t * job, pointf * A, int n, int filled)
     int i;
 
     shape = newSWFShape();
-    SWFShape_setLineStyle(shape, obj->penwidth * 20,
+    SWFShape_setLine(shape, obj->penwidth,
 	 pencolor.u.rgba[0],
 	 pencolor.u.rgba[1],
 	 pencolor.u.rgba[2],
@@ -207,14 +216,14 @@ static void
 ming_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
 		int arrow_at_end, int filled)
 {
-    SWFMovie movie = (SWFMovie)(job->surface);
+    SWFMovie movie = (SWFMovie)(job->context);
     SWFShape shape;
     obj_state_t *obj = job->obj;
     gvcolor_t pencolor = obj->pencolor;
     int i;
 
     shape = newSWFShape();
-    SWFShape_setLineStyle(shape, obj->penwidth * 20,
+    SWFShape_setLine(shape, obj->penwidth,
 	 pencolor.u.rgba[0],
 	 pencolor.u.rgba[1],
 	 pencolor.u.rgba[2],
@@ -229,14 +238,14 @@ ming_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
 static void
 ming_polyline(GVJ_t * job, pointf * A, int n)
 {
-    SWFMovie movie = (SWFMovie)(job->surface);
+    SWFMovie movie = (SWFMovie)(job->context);
     SWFShape shape;
     obj_state_t *obj = job->obj;
     gvcolor_t pencolor = obj->pencolor;
     int i;
 
     shape = newSWFShape();
-    SWFShape_setLineStyle(shape, obj->penwidth * 20,
+    SWFShape_setLine(shape, obj->penwidth,
 	 pencolor.u.rgba[0],
 	 pencolor.u.rgba[1],
 	 pencolor.u.rgba[2],
@@ -278,24 +287,29 @@ static gvrender_engine_t ming_engine = {
     0,				/* ming_library_shape */
 };
 
-static gvrender_features_t ming_features = {
-    (	GVRENDER_DOES_MULTIGRAPH_OUTPUT_FILES
-	| GVRENDER_DOES_TRUECOLOR
-	| GVRENDER_Y_GOES_DOWN
-//	| GVRENDER_DOES_TRANSFORM
-    ),				/* feature flags */
-    0,				/* default margin - points */
+static gvrender_features_t render_features_ming = {
+    GVRENDER_Y_GOES_DOWN,	/* flags */
     4.,                         /* default pad - graph units */
-    {0.,0.},                    /* default page width, height - points */
-    {96.,96.},			/* default dpi */
     0,				/* knowncolors */
     0,				/* sizeof knowncolors */
     RGBA_BYTE,			/* color_type */
-    NULL,			/* device */
-    NULL,			/* gvloadimage target for usershapes */
+};
+
+static gvdevice_features_t device_features_ming = {
+    GVDEVICE_DOES_PAGES
+	| GVDEVICE_NO_WRITER
+	| GVDEVICE_DOES_TRUECOLOR, /* flags */
+    {0.,0.},			/* default margin - points */
+    {0.,0.},                    /* default page width, height - points */
+    {96.,96.},			/* default dpi */
 };
 
 gvplugin_installed_t gvrender_ming_types[] = {
-    {FORMAT_SWF, "swf", 10, &ming_engine, &ming_features},
+    {FORMAT_SWF, "ming", 10, &ming_engine, &render_features_ming},
+    {0, NULL, 0, NULL, NULL}
+};
+
+gvplugin_installed_t gvdevice_ming_types[] = {
+    {FORMAT_SWF, "swf:ming", 10, NULL, &device_features_ming},
     {0, NULL, 0, NULL, NULL}
 };
