@@ -1,4 +1,4 @@
-  /* $Id: gvtextlayout_pango.c,v 1.37 2008/03/09 02:35:38 ellson Exp $ $Revision: 1.37 $ */
+  /* $Id: gvtextlayout_pango.c,v 1.41 2008/05/23 02:24:10 ellson Exp $ $Revision: 1.41 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /*********************************************************
@@ -24,7 +24,7 @@
 
 #ifdef HAVE_PANGOCAIRO
 #include <pango/pangocairo.h>
-#ifdef HAVE_FONTCONFIG
+#ifdef HAVE_PANGO_FC_FONT_LOCK_FACE
 #include <pango/pangofc-font.h>
 #endif
 
@@ -87,45 +87,44 @@ static boolean pango_textlayout(textpara_t * para, char **fontpath)
 
         if (fontpath) {  /* -v support */
 	    PangoFont *font;
+	    const char *fontclass;
 
             font = pango_font_map_load_font(fontmap, context, desc);
+	    fontclass = G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(font));
 
 	    buf[0] = '\0';
 	    if (psfnt)
 		strcat(buf, "(ps) ");
-#ifdef HAVE_FONTCONFIG
-	    {
+#ifdef HAVE_PANGO_FC_FONT_LOCK_FACE
+	    if (strcmp(fontclass, "PangoCairoFcFont") == 0) {
 	        FT_Face face;
 	        PangoFcFont *fcfont;
 	        FT_Stream stream;
 	        FT_StreamDesc streamdesc;
 	        fcfont = PANGO_FC_FONT(font);
-	        if (fcfont) {
-	            face = pango_fc_font_lock_face(fcfont);
-	            if (face) {
-		        strcat(buf, "\"");
-		        strcat(buf, face->family_name);
-		        strcat(buf, ", ");
-		        strcat(buf, face->style_name);
-		        strcat(buf, "\" ");
+	        face = pango_fc_font_lock_face(fcfont);
+	        if (face) {
+		    strcat(buf, "\"");
+		    strcat(buf, face->family_name);
+		    strcat(buf, ", ");
+		    strcat(buf, face->style_name);
+		    strcat(buf, "\" ");
     
-		        stream = face->stream;
-		        if (stream) {
-			    streamdesc = stream->pathname;
-			    if (streamdesc.pointer)
-			        strcat(buf, (char*)streamdesc.pointer);
-		            else
-			        strcat(buf, "*no pathname available*");
-		        }
+		    stream = face->stream;
+		    if (stream) {
+			streamdesc = stream->pathname;
+			if (streamdesc.pointer)
+			    strcat(buf, (char*)streamdesc.pointer);
 		        else
-			    strcat(buf, "*no stream available*");
+			    strcat(buf, "*no pathname available*");
 		    }
-	            pango_fc_font_unlock_face(fcfont);
-	        }
-	        else
-	            strcat(buf, "*not using fontconfig*");
+		    else
+			strcat(buf, "*no stream available*");
+		}
+	        pango_fc_font_unlock_face(fcfont);
 	    }
-#else
+	    else
+#endif
 	    {
     		PangoFontDescription *tdesc;
 		char *tfont;
@@ -137,7 +136,6 @@ static boolean pango_textlayout(textpara_t * para, char **fontpath)
 	        strcat(buf, "\" ");
 	        g_free(tfont);
 	    }
-#endif
             *fontpath = buf;
         }
     }
