@@ -6,8 +6,10 @@ array set LANGS {
                 	Agedge_t* SWIGTYPE_p_Agedge_t
                 	Agsym_t* SWIGTYPE_p_Agsym_t
                 	char* string
+                	char** outdata
                 	FILE* SWIGTYPE_p_FILE
                 	bool bool
+			int int
                 	void {}
 		}
 		SYNTAX {
@@ -36,6 +38,7 @@ array set LANGS {
 			{char* filename} filename
 			{char* engine} engine
 			{char* string} string
+			{char** outdata} outdata
 			{char* format} format
 			{FILE* f} channel
 			{void** data} data_handle
@@ -44,8 +47,10 @@ array set LANGS {
 			Agedge_t* edge_handle
 			Agsym_t* attribute_handle
 			char* string
+			char** outdata
 			FILE* channel
 			bool bool
+			int int
                 	void** data_handle
 			void {}
 		}
@@ -76,6 +81,7 @@ array set LANGS {
 			{char* filename} filename
 			{char* engine} engine
 			{char* string} string
+			{char** outdata} outdata
 			{char* format} format
 			{FILE* f} channel
 			{void** data} data_handle
@@ -84,8 +90,10 @@ array set LANGS {
 			Agedge_t* edge_handle
 			Agsym_t* attribute_handle
 			char* string
+			char** outdata
 			FILE* channel
 			bool bool
+			int int
 			void** data_handle
 			void {}
 		}
@@ -104,8 +112,10 @@ array set LANGS {
 			Agedge_t* SWIGTYPE_p_Agedge_t
 			Agsym_t* SWIGTYPE_p_Agsym_t
 			char* string
+			char** outdata
 			FILE* SWIGTYPE_p_FILE
 			bool bool
+			int int
 			void {}
 		}
 		SYNTAX {
@@ -135,6 +145,7 @@ array set LANGS {
 			{char* filename} filename
 			{char* engine} engine
 			{char* string} string
+			{char** outdata} outdata
 			{char* format} format
 			{FILE* f} channel
 			{void** data} data_handle
@@ -143,8 +154,10 @@ array set LANGS {
 			Agedge_t* edge_handle
 			Agsym_t* attribute_handle
 			char* string
+			char** outdata
 			FILE* channel
 			bool bool
+			int int
 			void** data_handle
 			void {}
 		}
@@ -153,8 +166,7 @@ array set LANGS {
 		}
 		SYNOPSIS {
 			{#!/usr/bin/lua}
-			{lib=loadlib('/usr/lib/graphviz/lua/libgv_lua.so','Gv_Init')}
-			{assert(lib)()}
+			{require('gv')}
 		}
 		USAGE {
 		}
@@ -177,6 +189,7 @@ array set LANGS {
 			{char* filename} filename
 			{char* engine} engine
 			{char* string} string
+			{char** outdata} outdata
 			{char* format} format
 			{FILE* f} channel
 			{void** data} data_handle
@@ -185,8 +198,10 @@ array set LANGS {
 			Agedge_t* edge_handle
 			Agsym_t* attribute_handle
 			char* string
+			char** outdata
 			FILE* channel
 			bool bool
+			int int
 			void** data_handle
 			void {}
 		}
@@ -216,6 +231,7 @@ array set LANGS {
 			{char* filename} filename
 			{char* engine} engine
 			{char* string} string
+			{char** outdata} outdata
 			{char* format} format
 			{FILE* f} channel
 			{void** data} data_handle
@@ -224,8 +240,10 @@ array set LANGS {
 			Agedge_t* edge_handle
 			Agsym_t* attribute_handle
 			char* string
+			char** outdata
 			FILE* channel
 			bool bool
+			int int
 			void** data_handle
 			void {}
 		}
@@ -234,7 +252,6 @@ array set LANGS {
 		}
 		SYNOPSIS {
 			{#!/usr/bin/perl}
-			{use lib "/usr/lib/graphviz/perl"}
 			{use gv;}
 		}
 		USAGE {
@@ -258,6 +275,7 @@ array set LANGS {
 			{char* filename} filename
 			{char* engine} engine
 			{char* string} string
+			{char** outdata} outdata
 			{char* format} format
 			{FILE* f} channel
 			{void** data} data_handle
@@ -266,8 +284,10 @@ array set LANGS {
 			Agedge_t* edge_handle
 			Agsym_t* attribute_handle
 			char* string
+			char** outdata
 			FILE* channel
 			bool bool
+			int int
 			void** data_handle
 			void {}
 		}
@@ -275,8 +295,11 @@ array set LANGS {
 			gv:: (  {, }   {);}
 		}
 		SYNOPSIS {
-			{dl("libgv_php.so");}
+			{#!/usr/bin/php}
+			{<?}
 			{include("gv.php")}
+			{...}
+			{?>}
 		}
 		USAGE {
 		}
@@ -299,6 +322,7 @@ array set LANGS {
 			{char* filename} filename
 			{char* engine} engine
 			{char* string} string
+			{char** outdata} outdata
 			{char* format} format
 			{FILE* f} channel
 			{void** data} data_handle
@@ -307,8 +331,10 @@ array set LANGS {
 			Agedge_t* edge_handle
 			Agsym_t* attribute_handle
 			char* string
+			char** outdata
 			FILE* channel
 			bool bool
+			int int
 			void** data_handle
 			void {}
 		}
@@ -318,7 +344,6 @@ array set LANGS {
 		SYNOPSIS {
 			{#!/usr/bin/python}
 			{import sys}
-			{sys.path.append('/usr/lib/graphviz/python')}
 			{import gv}
 		}
 		USAGE {
@@ -331,8 +356,10 @@ array set LANGS {
 			Agedge_t* SWIGTYPE_p_Agedge_t
 			Agsym_t* SWIGTYPE_p_Agsym_t
 			char* string
+			char** outdata
 			FILE* SWIGTYPE_p_FILE
 			bool bool
+			int int
 			void {}
 		}
 		SYNTAX {
@@ -362,6 +389,7 @@ array set LANGS {
 			{char* filename} filename
 			{char* engine} engine
 			{char* string} string
+			{char** outdata} outdata
 			{char* format} format
 			{FILE* f} channel
 			{void** data} data_handle
@@ -370,8 +398,10 @@ array set LANGS {
 			Agedge_t* edge_handle
 			Agsym_t* attribute_handle
 			char* string
+			char** outdata
 			FILE* channel
 			bool bool
+			int int
 			void** data_handle
 			void {}
 		}
@@ -379,8 +409,6 @@ array set LANGS {
 			Gv.  (  {, }   {);}
 		}
 		SYNOPSIS {
-			{export RUBYLIB=/usr/lib/graphviz/ruby}
-			{}
 			{#!/usr/bin/ruby}
 			{require 'gv'}
 		}
@@ -405,6 +433,7 @@ array set LANGS {
 			{char* filename} <filename>
 			{char* engine} <engine>
 			{char* string} <string>
+			{char** outdata} <outdata>
 			{char* format} <format>
 			{FILE* f} <channel>
 			{void** data} <data_handle>
@@ -413,8 +442,10 @@ array set LANGS {
 			Agedge_t* <edge_handle>
 			Agsym_t* <attr_handle>
 			char* <string>
+			char** <outdata>
 			FILE* <channel>
 			bool <boolean_string>
+			int <integer_string>
 			void** <data_handle>
 			void {}
 		}
@@ -423,10 +454,10 @@ array set LANGS {
 		}
 		SYNOPSIS {
 			{#!/usr/bin/tclsh}
-			{load /usr/lib/graphviz/tcl/gv.so}
+			{package require gv}
 		}
 		USAGE {
-			{Requires tcl7.6 or later.}
+			{Requires tcl8.3 or later.}
 		}
 	}
 }
